Class: Google::Apis::ServicemanagementV1::Aspect

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Aspect represents Generic aspect. It is used to configure an aspect without making direct changes to service.proto

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Aspect

Returns a new instance of Aspect.



147
148
149
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

The type of this aspect configuration. Corresponds to the JSON property kind

Returns:

  • (String)


139
140
141
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 139

def kind
  @kind
end

#specHash<String,Object>

Content of the configuration. The underlying schema should be defined by Aspect owners as protobuf message under google/api/configaspects/proto. Corresponds to the JSON property spec

Returns:

  • (Hash<String,Object>)


145
146
147
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 145

def spec
  @spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



152
153
154
155
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 152

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @spec = args[:spec] if args.key?(:spec)
end