Class: Google::Apis::ServicemanagementV1::ChangeReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Change report associated with a particular service configuration. It contains a list of ConfigChanges based on the comparison between two service configurations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChangeReport

Returns a new instance of ChangeReport.



900
901
902
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_changesArray<Google::Apis::ServicemanagementV1::ConfigChange>

List of changes between two service configurations. The changes will be alphabetically sorted based on the identifier of each change. A ConfigChange identifier is a dot separated path to the configuration. Example: visibility. rules[selector='LibraryService.CreateBook'].restriction Corresponds to the JSON property configChanges



898
899
900
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 898

def config_changes
  @config_changes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



905
906
907
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 905

def update!(**args)
  @config_changes = args[:config_changes] if args.key?(:config_changes)
end