Class: Google::Apis::ServicemanagementV1::Diagnostic
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Diagnostic
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Represents a diagnostic message (error or warning)
Instance Attribute Summary collapse
-
#kind ⇒ String
The kind of diagnostic information provided.
-
#location ⇒ String
File name and line number of the error or warning.
-
#message ⇒ String
Message describing the error or warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Diagnostic
constructor
A new instance of Diagnostic.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Diagnostic
Returns a new instance of Diagnostic.
1372 1373 1374 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1372 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
The kind of diagnostic information provided.
Corresponds to the JSON property kind
1360 1361 1362 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1360 def kind @kind end |
#location ⇒ String
File name and line number of the error or warning.
Corresponds to the JSON property location
1365 1366 1367 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1365 def location @location end |
#message ⇒ String
Message describing the error or warning.
Corresponds to the JSON property message
1370 1371 1372 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1370 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1377 1378 1379 1380 1381 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1377 def update!(**args) @kind = args[:kind] if args.key?(:kind) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |