Class: Google::Apis::ServicemanagementV1::Documentation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Documentation provides the information for describing a service. Example: documentation: summary: > The Google Calendar API gives access to most calendar features. pages: - name: Overview content: (== include google/foo/ overview.md ==) - name: Tutorial content: (== include google/foo/tutorial.md == ) subpages: - name: Java content: (== include google/foo/tutorial_java.md ==) rules: - selector: google.calendar.Calendar.Get description: > ... - selector: google.calendar.Calendar.Put description: > ... Documentation is provided in markdown syntax. In addition to standard markdown features, definition lists, tables and fenced code blocks are supported. Section headers can be provided and are interpreted relative to the section nesting of the context where a documentation fragment is embedded. Documentation from the IDL is merged with documentation defined via the config at normalization time, where documentation provided by config rules overrides IDL provided. A number of constructs specific to the API platform are supported in documentation text. In order to reference a proto element, the following notation can be used: [ fully.qualified.proto.name][] To override the display text used for the link, this can be used: [display text][fully.qualified.proto.name] Text can be excluded from doc using the following notation: (-- internal comment --) A few directives are available in documentation. Note that directives must appear on a single line to be properly identified. The include directive includes a markdown file from an external source: (== include path/to/file ==) The resource_for directive marks a message to be the resource of a collection in REST view. If it is not specified, tools attempt to infer the resource from the operations in a collection: (== resource_for v1.shelves.books ==) The directive suppress_warning does not directly affect documentation and is documented together with service config validation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Documentation

Returns a new instance of Documentation.



1497
1498
1499
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_iam_infoString

Optional information about the IAM configuration. This is typically used to link to documentation about a product's IAM roles and permissions. Corresponds to the JSON property additionalIamInfo

Returns:

  • (String)


1450
1451
1452
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1450

def additional_iam_info
  @additional_iam_info
end

#documentation_root_urlString

The URL to the root of documentation. Corresponds to the JSON property documentationRootUrl

Returns:

  • (String)


1455
1456
1457
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1455

def documentation_root_url
  @documentation_root_url
end

#overviewString

Declares a single overview page. For example: documentation: summary: ... overview: (== include overview.md ==) This is a shortcut for the following declaration (using pages style): documentation: summary: ... pages: - name: Overview content: (== include overview.md ==) Note: you cannot specify both overview field and pages field. Corresponds to the JSON property overview

Returns:

  • (String)


1464
1465
1466
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1464

def overview
  @overview
end

#pagesArray<Google::Apis::ServicemanagementV1::Page>

The top level pages for the documentation set. Corresponds to the JSON property pages



1469
1470
1471
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1469

def pages
  @pages
end

#rulesArray<Google::Apis::ServicemanagementV1::DocumentationRule>

A list of documentation rules that apply to individual API elements. NOTE: All service configuration rules follow "last one wins" order. Corresponds to the JSON property rules



1475
1476
1477
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1475

def rules
  @rules
end

#section_overridesArray<Google::Apis::ServicemanagementV1::Page>

Specifies section and content to override the boilerplate content. Currently overrides following sections: 1. rest.service.client_libraries Corresponds to the JSON property sectionOverrides



1481
1482
1483
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1481

def section_overrides
  @section_overrides
end

#service_root_urlString

Specifies the service root url if the default one (the service name from the yaml file) is not suitable. This can be seen in any fully specified service urls as well as sections that show a base that other urls are relative to. Corresponds to the JSON property serviceRootUrl

Returns:

  • (String)


1488
1489
1490
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1488

def service_root_url
  @service_root_url
end

#summaryString

A short description of what the service does. The summary must be plain text. It becomes the overview of the service displayed in Google Cloud Console. NOTE: This field is equivalent to the standard field description. Corresponds to the JSON property summary

Returns:

  • (String)


1495
1496
1497
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1495

def summary
  @summary
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1502
1503
1504
1505
1506
1507
1508
1509
1510
1511
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1502

def update!(**args)
  @additional_iam_info = args[:additional_iam_info] if args.key?(:additional_iam_info)
  @documentation_root_url = args[:documentation_root_url] if args.key?(:documentation_root_url)
  @overview = args[:overview] if args.key?(:overview)
  @pages = args[:pages] if args.key?(:pages)
  @rules = args[:rules] if args.key?(:rules)
  @section_overrides = args[:section_overrides] if args.key?(:section_overrides)
  @service_root_url = args[:service_root_url] if args.key?(:service_root_url)
  @summary = args[:summary] if args.key?(:summary)
end