Class: Google::Apis::ServicemanagementV1::GenerateConfigReportResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Response message for GenerateConfigReport method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenerateConfigReportResponse

Returns a new instance of GenerateConfigReportResponse.



2088
2089
2090
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2088

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#change_reportsArray<Google::Apis::ServicemanagementV1::ChangeReport>

list of ChangeReport, each corresponding to comparison between two service configurations. Corresponds to the JSON property changeReports



2070
2071
2072
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2070

def change_reports
  @change_reports
end

#diagnosticsArray<Google::Apis::ServicemanagementV1::Diagnostic>

Errors / Linter warnings associated with the service definition this report belongs to. Corresponds to the JSON property diagnostics



2076
2077
2078
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2076

def diagnostics
  @diagnostics
end

#idString

ID of the service configuration this report belongs to. Corresponds to the JSON property id

Returns:

  • (String)


2081
2082
2083
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2081

def id
  @id
end

#service_nameString

Name of the service this report belongs to. Corresponds to the JSON property serviceName

Returns:

  • (String)


2086
2087
2088
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2086

def service_name
  @service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2093
2094
2095
2096
2097
2098
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2093

def update!(**args)
  @change_reports = args[:change_reports] if args.key?(:change_reports)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @id = args[:id] if args.key?(:id)
  @service_name = args[:service_name] if args.key?(:service_name)
end