Class: Google::Apis::ServicemanagementV1::MethodSettings
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::MethodSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Describes the generator configuration for a method.
Instance Attribute Summary collapse
-
#auto_populated_fields ⇒ Array<String>
List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info).
-
#batching ⇒ Google::Apis::ServicemanagementV1::BatchingConfigProto
BatchingConfigProtodefines the batching configuration for an API method. -
#long_running ⇒ Google::Apis::ServicemanagementV1::LongRunning
Describes settings to use when generating API methods that use the long- running operation pattern.
-
#selector ⇒ String
The fully qualified name of the method, for which the options below apply.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MethodSettings
constructor
A new instance of MethodSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MethodSettings
Returns a new instance of MethodSettings.
2958 2959 2960 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_populated_fields ⇒ Array<String>
List of top-level fields of the request message, that should be automatically
populated by the client libraries based on their (google.api.field_info).
format. Currently supported format: UUID4. Example of a YAML configuration:
publishing: method_settings: - selector: google.example.v1.ExampleService.
CreateExample auto_populated_fields: - request_id
Corresponds to the JSON property autoPopulatedFields
2934 2935 2936 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2934 def auto_populated_fields @auto_populated_fields end |
#batching ⇒ Google::Apis::ServicemanagementV1::BatchingConfigProto
BatchingConfigProto defines the batching configuration for an API method.
Corresponds to the JSON property batching
2939 2940 2941 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2939 def batching @batching end |
#long_running ⇒ Google::Apis::ServicemanagementV1::LongRunning
Describes settings to use when generating API methods that use the long-
running operation pattern. All default values below are from those used in the
client library generators (e.g. Java).
Corresponds to the JSON property longRunning
2948 2949 2950 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2948 def long_running @long_running end |
#selector ⇒ String
The fully qualified name of the method, for which the options below apply.
This is used to find the method to apply the options. Example: publishing:
method_settings: - selector: google.storage.control.v2.StorageControl.
CreateFolder # method settings for CreateFolder...
Corresponds to the JSON property selector
2956 2957 2958 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2956 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2963 2964 2965 2966 2967 2968 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2963 def update!(**args) @auto_populated_fields = args[:auto_populated_fields] if args.key?(:auto_populated_fields) @batching = args[:batching] if args.key?(:batching) @long_running = args[:long_running] if args.key?(:long_running) @selector = args[:selector] if args.key?(:selector) end |