Class: Google::Apis::ServicemanagementV1::MonitoringDestination
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::MonitoringDestination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Configuration of a specific monitoring destination (the producer project or the consumer project).
Instance Attribute Summary collapse
-
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination.
-
#monitored_resource ⇒ String
The monitored resource type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MonitoringDestination
constructor
A new instance of MonitoringDestination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MonitoringDestination
Returns a new instance of MonitoringDestination.
3401 3402 3403 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metrics ⇒ Array<String>
Types of the metrics to report to this monitoring destination. Each type must
be defined in Service.metrics section.
Corresponds to the JSON property metrics
3393 3394 3395 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3393 def metrics @metrics end |
#monitored_resource ⇒ String
The monitored resource type. The type must be defined in Service.
monitored_resources section.
Corresponds to the JSON property monitoredResource
3399 3400 3401 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3399 def monitored_resource @monitored_resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3406 3407 3408 3409 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3406 def update!(**args) @metrics = args[:metrics] if args.key?(:metrics) @monitored_resource = args[:monitored_resource] if args.key?(:monitored_resource) end |