Class: Google::Apis::ServicemanagementV1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

The metadata associated with a long running operation resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



3586
3587
3588
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3586

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#progress_percentageFixnum

Percentage of completion of this operation, ranging from 0 to 100. Corresponds to the JSON property progressPercentage

Returns:

  • (Fixnum)


3569
3570
3571
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3569

def progress_percentage
  @progress_percentage
end

#resource_namesArray<String>

The full name of the resources that this operation is directly associated with. Corresponds to the JSON property resourceNames

Returns:

  • (Array<String>)


3574
3575
3576
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3574

def resource_names
  @resource_names
end

#start_timeString

The start time of the operation. Corresponds to the JSON property startTime

Returns:

  • (String)


3579
3580
3581
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3579

def start_time
  @start_time
end

#stepsArray<Google::Apis::ServicemanagementV1::Step>

Detailed status information for each step. The order is undetermined. Corresponds to the JSON property steps



3584
3585
3586
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3584

def steps
  @steps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3591
3592
3593
3594
3595
3596
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3591

def update!(**args)
  @progress_percentage = args[:progress_percentage] if args.key?(:progress_percentage)
  @resource_names = args[:resource_names] if args.key?(:resource_names)
  @start_time = args[:start_time] if args.key?(:start_time)
  @steps = args[:steps] if args.key?(:steps)
end