Class: Google::Apis::ServicemanagementV1::Page

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Represents a documentation page. A page can contain subpages to represent nested documentation set structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Page

Returns a new instance of Page.



3662
3663
3664
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentString

The Markdown content of the page. You can use (== include `path` ==) to include content from a Markdown file. The content can be used to produce the documentation page such as HTML format page. Corresponds to the JSON property content

Returns:

  • (String)


3643
3644
3645
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3643

def content
  @content
end

#nameString

The name of the page. It will be used as an identity of the page to generate URI of the page, text of the link to this page in navigation, etc. The full page name (start from the root page name to this page concatenated with .) can be used as reference to the page in your documentation. For example: pages:

  • name: Tutorial content: (== include tutorial.md ==) subpages: - name: Java content: (== include tutorial_java.md ==) You can reference Java page using Markdown reference link syntax: Java. Corresponds to the JSON property name

Returns:

  • (String)


3654
3655
3656
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3654

def name
  @name
end

#subpagesArray<Google::Apis::ServicemanagementV1::Page>

Subpages of this page. The order of subpages specified here will be honored in the generated docset. Corresponds to the JSON property subpages



3660
3661
3662
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3660

def subpages
  @subpages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3667
3668
3669
3670
3671
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3667

def update!(**args)
  @content = args[:content] if args.key?(:content)
  @name = args[:name] if args.key?(:name)
  @subpages = args[:subpages] if args.key?(:subpages)
end