Class: Google::Apis::ServicemanagementV1::Service
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Service is the root object of Google API service configuration (service
config). It describes the basic information about a logical service, such as
the service name and the user-facing title, and delegates other aspects to sub-
sections. Each sub-section is either a proto message or a repeated proto
message that configures a specific aspect, such as auth. For more information,
see each proto message definition. Example: type: google.api.Service name:
calendar.googleapis.com title: Google Calendar API apis: - name: google.
calendar.v3.Calendar visibility: rules: - selector: "google.calendar.v3."
restriction: PREVIEW backend: rules: - selector: "google.calendar.v3."
address: calendar.example.com authentication: providers: - id:
google_calendar_auth jwks_uri: https://www.googleapis.com/oauth2/v1/certs
issuer: https://securetoken.google.com rules: - selector: "*" requirements:
provider_id: google_calendar_auth
Instance Attribute Summary collapse
-
#apis ⇒ Array<Google::Apis::ServicemanagementV1::Api>
A list of API interfaces exported by this service.
-
#aspects ⇒ Array<Google::Apis::ServicemanagementV1::Aspect>
Configuration aspects.
-
#authentication ⇒ Google::Apis::ServicemanagementV1::Authentication
Authenticationdefines the authentication configuration for API methods provided by an API service. -
#backend ⇒ Google::Apis::ServicemanagementV1::Backend
Backenddefines the backend configuration for a service. -
#billing ⇒ Google::Apis::ServicemanagementV1::Billing
Billing related configuration of the service.
-
#config_version ⇒ Fixnum
Obsolete.
-
#context ⇒ Google::Apis::ServicemanagementV1::Context
Contextdefines which contexts an API requests. -
#control ⇒ Google::Apis::ServicemanagementV1::Control
Selects and configures the service controller used by the service.
-
#custom_error ⇒ Google::Apis::ServicemanagementV1::CustomError
Customize service error responses.
-
#documentation ⇒ Google::Apis::ServicemanagementV1::Documentation
Documentationprovides the information for describing a service. -
#endpoints ⇒ Array<Google::Apis::ServicemanagementV1::Endpoint>
Configuration for network endpoints.
-
#enums ⇒ Array<Google::Apis::ServicemanagementV1::Enum>
A list of all enum types included in this API service.
-
#http ⇒ Google::Apis::ServicemanagementV1::Http
Defines the HTTP configuration for an API service.
-
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the client for tracking purpose.
-
#logging ⇒ Google::Apis::ServicemanagementV1::Logging
Logging configuration of the service.
-
#logs ⇒ Array<Google::Apis::ServicemanagementV1::LogDescriptor>
Defines the logs used by this service.
-
#metrics ⇒ Array<Google::Apis::ServicemanagementV1::MetricDescriptor>
Defines the metrics used by this service.
-
#monitored_resources ⇒ Array<Google::Apis::ServicemanagementV1::MonitoredResourceDescriptor>
Defines the monitored resources used by this service.
-
#monitoring ⇒ Google::Apis::ServicemanagementV1::Monitoring
Monitoring configuration of the service.
-
#name ⇒ String
The service name, which is a DNS-like logical identifier for the service, such as
calendar.googleapis.com. -
#producer_project_id ⇒ String
The Google project that owns this service.
-
#publishing ⇒ Google::Apis::ServicemanagementV1::Publishing
This message configures the settings for publishing Google Cloud Client libraries generated from the service config.
-
#quota ⇒ Google::Apis::ServicemanagementV1::Quota
Quota configuration helps to achieve fairness and budgeting in service usage.
-
#source_info ⇒ Google::Apis::ServicemanagementV1::SourceInfo
Source information used to create a Service Config Corresponds to the JSON property
sourceInfo. -
#system_parameters ⇒ Google::Apis::ServicemanagementV1::SystemParameters
System parameter configuration A system parameter is a special kind of parameter defined by the API system, not by an individual API.
-
#system_types ⇒ Array<Google::Apis::ServicemanagementV1::Type>
A list of all proto message types included in this API service.
-
#title ⇒ String
The product title for this service, it is the name displayed in Google Cloud Console.
-
#types ⇒ Array<Google::Apis::ServicemanagementV1::Type>
A list of all proto message types included in this API service.
-
#usage ⇒ Google::Apis::ServicemanagementV1::Usage
Configuration controlling usage of a service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
4516 4517 4518 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#apis ⇒ Array<Google::Apis::ServicemanagementV1::Api>
A list of API interfaces exported by this service. Only the name field of
the google.protobuf.Api needs to be provided by the configuration author, as
the remaining fields will be derived from the IDL during the normalization
process. It is an error to specify an API interface here which cannot be
resolved against the associated IDL files.
Corresponds to the JSON property apis
4228 4229 4230 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4228 def apis @apis end |
#aspects ⇒ Array<Google::Apis::ServicemanagementV1::Aspect>
Configuration aspects. This is a repeated field to allow multiple aspects to
be configured. The kind field in each ConfigAspect specifies the type of
aspect. The spec field contains the configuration for that aspect. The schema
for the spec field is defined by the backend service owners.
Corresponds to the JSON property aspects
4236 4237 4238 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4236 def aspects @aspects end |
#authentication ⇒ Google::Apis::ServicemanagementV1::Authentication
Authentication defines the authentication configuration for API methods
provided by an API service. Example: name: calendar.googleapis.com
authentication: providers: - id: google_calendar_auth jwks_uri: https://www.
googleapis.com/oauth2/v1/certs issuer: https://securetoken.google.com rules: -
selector: "*" requirements: provider_id: google_calendar_auth - selector:
google.calendar.Delegate oauth: canonical_scopes: https://www.googleapis.com/
auth/calendar.read
Corresponds to the JSON property authentication
4247 4248 4249 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4247 def authentication @authentication end |
#backend ⇒ Google::Apis::ServicemanagementV1::Backend
Backend defines the backend configuration for a service.
Corresponds to the JSON property backend
4252 4253 4254 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4252 def backend @backend end |
#billing ⇒ Google::Apis::ServicemanagementV1::Billing
Billing related configuration of the service. The following example shows how
to configure monitored resources and metrics for billing,
consumer_destinations is the only supported destination and the monitored
resources need at least one label key cloud.googleapis.com/location to
indicate the location of the billing usage, using different monitored
resources between monitoring and billing is recommended so they can be evolved
independently: monitored_resources: - type: library.googleapis.com/
billing_branch labels: - key: cloud.googleapis.com/location description: |
Predefined label to support billing location restriction. - key: city
description: | Custom label to define the city where the library branch is
located in. - key: name description: Custom label to define the name of the
library branch. metrics: - name: library.googleapis.com/book/borrowed_count
metric_kind: DELTA value_type: INT64 unit: "1" billing: consumer_destinations:
- monitored_resource: library.googleapis.com/billing_branch metrics: - library.
googleapis.com/book/borrowed_count
Corresponds to the JSON property
billing
4271 4272 4273 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4271 def billing @billing end |
#config_version ⇒ Fixnum
Obsolete. Do not use. This field has no semantic meaning. The service config
compiler always sets this field to 3.
Corresponds to the JSON property configVersion
4277 4278 4279 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4277 def config_version @config_version end |
#context ⇒ Google::Apis::ServicemanagementV1::Context
Context defines which contexts an API requests. Example: context: rules: -
selector: "*" requested: - google.rpc.context.ProjectContext - google.rpc.
context.OriginContext The above specifies that all methods in the API request
google.rpc.context.ProjectContext and google.rpc.context.OriginContext.
Available context types are defined in package google.rpc.context. This also
provides mechanism to allowlist any protobuf message extension that can be
sent in grpc metadata using “x-goog-ext--bin” and “x-goog-ext--jspb” format.
For example, list any service specific protobuf types that can appear in grpc
metadata as follows in your yaml file: Example: context: rules: - selector: "
google.example.library.v1.LibraryService.CreateBook"
allowed_request_extensions: - google.foo.v1.NewExtension
allowed_response_extensions: - google.foo.v1.NewExtension You can also specify
extension ID instead of fully qualified extension name here.
Corresponds to the JSON property context
4294 4295 4296 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4294 def context @context end |
#control ⇒ Google::Apis::ServicemanagementV1::Control
Selects and configures the service controller used by the service. Example:
control: environment: servicecontrol.googleapis.com
Corresponds to the JSON property control
4300 4301 4302 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4300 def control @control end |
#custom_error ⇒ Google::Apis::ServicemanagementV1::CustomError
Customize service error responses. For example, list any service specific
protobuf types that can appear in error detail lists of error responses.
Example: custom_error: types: - google.foo.v1.CustomError - google.foo.v1.
AnotherError
Corresponds to the JSON property customError
4308 4309 4310 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4308 def custom_error @custom_error end |
#documentation ⇒ Google::Apis::ServicemanagementV1::Documentation
Documentation provides the information for describing a service. Example:
documentation: summary: > The Google Calendar API gives access to most
calendar features. pages: - name: Overview content: (== include google/foo/
overview.md ==) - name: Tutorial content: (== include google/foo/tutorial.md ==
) subpages: - name: Java content: (== include google/foo/tutorial_java.md ==)
rules: - selector: google.calendar.Calendar.Get description: > ... - selector:
google.calendar.Calendar.Put description: > ... Documentation is provided in
markdown syntax. In addition to standard markdown features, definition lists,
tables and fenced code blocks are supported. Section headers can be provided
and are interpreted relative to the section nesting of the context where a
documentation fragment is embedded. Documentation from the IDL is merged with
documentation defined via the config at normalization time, where
documentation provided by config rules overrides IDL provided. A number of
constructs specific to the API platform are supported in documentation text.
In order to reference a proto element, the following notation can be used: [
fully.qualified.proto.name][] To override the display text used for the link,
this can be used: [display text][fully.qualified.proto.name] Text can be
excluded from doc using the following notation: (-- internal comment --) A few
directives are available in documentation. Note that directives must appear on
a single line to be properly identified. The include directive includes a
markdown file from an external source: (== include path/to/file ==) The
resource_for directive marks a message to be the resource of a collection in
REST view. If it is not specified, tools attempt to infer the resource from
the operations in a collection: (== resource_for v1.shelves.books ==) The
directive suppress_warning does not directly affect documentation and is
documented together with service config validation.
Corresponds to the JSON property documentation
4338 4339 4340 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4338 def documentation @documentation end |
#endpoints ⇒ Array<Google::Apis::ServicemanagementV1::Endpoint>
Configuration for network endpoints. If this is empty, then an endpoint with
the same name as the service is automatically generated to service all defined
APIs. WARNING: Defining any entries in the endpoints list disables the
automatic generation of default endpoint variations (e.g., service`.clients6.
google.com`, `content-`service`.googleapis.com`, and mTLS variants like
service.mtls.googleapis.com). To retain these default variations, you are
required to explicitly include your main service endpoint (e.g., myservice.
googleapis.com) in this list alongside any other custom endpoints (like REP,
GFE, etc.).
Corresponds to the JSON property endpoints
4351 4352 4353 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4351 def endpoints @endpoints end |
#enums ⇒ Array<Google::Apis::ServicemanagementV1::Enum>
A list of all enum types included in this API service. Enums referenced
directly or indirectly by the apis are automatically included. Enums which
are not referenced but shall be included should be listed here by name by the
configuration author. Example: enums: - name: google.someapi.v1.SomeEnum
Corresponds to the JSON property enums
4359 4360 4361 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4359 def enums @enums end |
#http ⇒ Google::Apis::ServicemanagementV1::Http
Defines the HTTP configuration for an API service. It contains a list of
HttpRule, each specifying the mapping of an RPC method to one or more HTTP
REST API methods.
Corresponds to the JSON property http
4366 4367 4368 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4366 def http @http end |
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the
client for tracking purpose. Must be no longer than 63 characters and only
lower case letters, digits, '.', '_' and '-' are allowed. If empty, the server
may choose to generate one instead.
Corresponds to the JSON property id
4374 4375 4376 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4374 def id @id end |
#logging ⇒ Google::Apis::ServicemanagementV1::Logging
Logging configuration of the service. The following example shows how to
configure logs to be sent to the producer and consumer projects. In the
example, the activity_history log is sent to both the producer and consumer
projects, whereas the purchase_history log is only sent to the producer
project. monitored_resources: - type: library.googleapis.com/branch labels: -
key: /city description: The city where the library branch is located in. - key:
/name description: The name of the branch. logs: - name: activity_history
labels: - key: /customer_id - name: purchase_history logging:
producer_destinations: - monitored_resource: library.googleapis.com/branch
logs: - activity_history - purchase_history consumer_destinations: -
monitored_resource: library.googleapis.com/branch logs: - activity_history
Corresponds to the JSON property logging
4389 4390 4391 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4389 def logging @logging end |
#logs ⇒ Array<Google::Apis::ServicemanagementV1::LogDescriptor>
Defines the logs used by this service.
Corresponds to the JSON property logs
4394 4395 4396 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4394 def logs @logs end |
#metrics ⇒ Array<Google::Apis::ServicemanagementV1::MetricDescriptor>
Defines the metrics used by this service.
Corresponds to the JSON property metrics
4399 4400 4401 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4399 def metrics @metrics end |
#monitored_resources ⇒ Array<Google::Apis::ServicemanagementV1::MonitoredResourceDescriptor>
Defines the monitored resources used by this service. This is required by the
Service.monitoring and Service.logging configurations.
Corresponds to the JSON property monitoredResources
4405 4406 4407 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4405 def monitored_resources @monitored_resources end |
#monitoring ⇒ Google::Apis::ServicemanagementV1::Monitoring
Monitoring configuration of the service. The example below shows how to
configure monitored resources and metrics for monitoring. In the example, a
monitored resource and two metrics are defined. The library.googleapis.com/
book/returned_count metric is sent to both producer and consumer projects,
whereas the library.googleapis.com/book/num_overdue metric is only sent to
the consumer project. monitored_resources: - type: library.googleapis.com/
Branch display_name: "Library Branch" description: "A branch of a library."
launch_stage: GA labels: - key: resource_container description: "The Cloud
container (ie. project id) for the Branch." - key: location description: "The
location of the library branch." - key: branch_id description: "The id of the
branch." metrics: - name: library.googleapis.com/book/returned_count
display_name: "Books Returned" description: "The count of books that have been
returned." launch_stage: GA metric_kind: DELTA value_type: INT64 unit: "1"
labels: - key: customer_id description: "The id of the customer." - name:
library.googleapis.com/book/num_overdue display_name: "Books Overdue"
description: "The current number of overdue books." launch_stage: GA
metric_kind: GAUGE value_type: INT64 unit: "1" labels: - key: customer_id
description: "The id of the customer." monitoring: producer_destinations: -
monitored_resource: library.googleapis.com/Branch metrics: - library.
googleapis.com/book/returned_count consumer_destinations: - monitored_resource:
library.googleapis.com/Branch metrics: - library.googleapis.com/book/
returned_count - library.googleapis.com/book/num_overdue
Corresponds to the JSON property monitoring
4431 4432 4433 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4431 def monitoring @monitoring end |
#name ⇒ String
The service name, which is a DNS-like logical identifier for the service, such
as calendar.googleapis.com. The service name typically goes through DNS
verification to make sure the owner of the service also owns the DNS name.
Corresponds to the JSON property name
4438 4439 4440 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4438 def name @name end |
#producer_project_id ⇒ String
The Google project that owns this service.
Corresponds to the JSON property producerProjectId
4443 4444 4445 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4443 def producer_project_id @producer_project_id end |
#publishing ⇒ Google::Apis::ServicemanagementV1::Publishing
This message configures the settings for publishing Google Cloud Client
libraries
generated from the service config.
Corresponds to the JSON property publishing
4450 4451 4452 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4450 def publishing @publishing end |
#quota ⇒ Google::Apis::ServicemanagementV1::Quota
Quota configuration helps to achieve fairness and budgeting in service usage.
The metric based quota configuration works this way: - The service
configuration defines a set of metrics. - For API calls, the quota.
metric_rules maps methods to metrics with corresponding costs. - The quota.
limits defines limits on the metrics, which will be used for quota checks at
runtime. An example quota configuration in yaml format: quota: limits: - name:
apiWriteQpsPerProject metric: library.googleapis.com/write_calls unit: "1/min/
project" # rate limit for consumer projects values: STANDARD: 10000 (The
metric rules bind all methods to the read_calls metric, except for the
UpdateBook and DeleteBook methods. These two methods are mapped to the
write_calls metric, with the UpdateBook method consuming at twice rate as the
DeleteBook method.) metric_rules: - selector: "*" metric_costs: library.
googleapis.com/read_calls: 1 - selector: google.example.library.v1.
LibraryService.UpdateBook metric_costs: library.googleapis.com/write_calls: 2 -
selector: google.example.library.v1.LibraryService.DeleteBook metric_costs:
library.googleapis.com/write_calls: 1 Corresponding Metric definition: metrics:
- name: library.googleapis.com/read_calls display_name: Read requests
metric_kind: DELTA value_type: INT64 - name: library.googleapis.com/
write_calls display_name: Write requests metric_kind: DELTA value_type: INT64
Corresponds to the JSON property
quota
4473 4474 4475 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4473 def quota @quota end |
#source_info ⇒ Google::Apis::ServicemanagementV1::SourceInfo
Source information used to create a Service Config
Corresponds to the JSON property sourceInfo
4478 4479 4480 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4478 def source_info @source_info end |
#system_parameters ⇒ Google::Apis::ServicemanagementV1::SystemParameters
System parameter configuration A system parameter is a special kind of
parameter defined by the API system, not by an individual API. It is typically
mapped to an HTTP header and/or a URL query parameter. This configuration
specifies which methods change the names of the system parameters.
Corresponds to the JSON property systemParameters
4486 4487 4488 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4486 def system_parameters @system_parameters end |
#system_types ⇒ Array<Google::Apis::ServicemanagementV1::Type>
A list of all proto message types included in this API service. It serves
similar purpose as [google.api.Service.types], except that these types are not
needed by user-defined APIs. Therefore, they will not show up in the generated
discovery doc. This field should only be used to define system APIs in ESF.
Corresponds to the JSON property systemTypes
4494 4495 4496 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4494 def system_types @system_types end |
#title ⇒ String
The product title for this service, it is the name displayed in Google Cloud
Console.
Corresponds to the JSON property title
4500 4501 4502 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4500 def title @title end |
#types ⇒ Array<Google::Apis::ServicemanagementV1::Type>
A list of all proto message types included in this API service. Types
referenced directly or indirectly by the apis are automatically included.
Messages which are not referenced but shall be included, such as types used by
the google.protobuf.Any type, should be listed here by name by the
configuration author. Example: types: - name: google.protobuf.Int32
Corresponds to the JSON property types
4509 4510 4511 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4509 def types @types end |
#usage ⇒ Google::Apis::ServicemanagementV1::Usage
Configuration controlling usage of a service.
Corresponds to the JSON property usage
4514 4515 4516 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4514 def usage @usage end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4521 4522 4523 4524 4525 4526 4527 4528 4529 4530 4531 4532 4533 4534 4535 4536 4537 4538 4539 4540 4541 4542 4543 4544 4545 4546 4547 4548 4549 4550 4551 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4521 def update!(**args) @apis = args[:apis] if args.key?(:apis) @aspects = args[:aspects] if args.key?(:aspects) @authentication = args[:authentication] if args.key?(:authentication) @backend = args[:backend] if args.key?(:backend) @billing = args[:billing] if args.key?(:billing) @config_version = args[:config_version] if args.key?(:config_version) @context = args[:context] if args.key?(:context) @control = args[:control] if args.key?(:control) @custom_error = args[:custom_error] if args.key?(:custom_error) @documentation = args[:documentation] if args.key?(:documentation) @endpoints = args[:endpoints] if args.key?(:endpoints) @enums = args[:enums] if args.key?(:enums) @http = args[:http] if args.key?(:http) @id = args[:id] if args.key?(:id) @logging = args[:logging] if args.key?(:logging) @logs = args[:logs] if args.key?(:logs) @metrics = args[:metrics] if args.key?(:metrics) @monitored_resources = args[:monitored_resources] if args.key?(:monitored_resources) @monitoring = args[:monitoring] if args.key?(:monitoring) @name = args[:name] if args.key?(:name) @producer_project_id = args[:producer_project_id] if args.key?(:producer_project_id) @publishing = args[:publishing] if args.key?(:publishing) @quota = args[:quota] if args.key?(:quota) @source_info = args[:source_info] if args.key?(:source_info) @system_parameters = args[:system_parameters] if args.key?(:system_parameters) @system_types = args[:system_types] if args.key?(:system_types) @title = args[:title] if args.key?(:title) @types = args[:types] if args.key?(:types) @usage = args[:usage] if args.key?(:usage) end |