Class: Google::Apis::ServicemanagementV1::BatchingConfigProto
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::BatchingConfigProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
BatchingConfigProto defines the batching configuration for an API method.
Instance Attribute Summary collapse
-
#batch_descriptor ⇒ Google::Apis::ServicemanagementV1::BatchingDescriptorProto
BatchingDescriptorProtospecifies the fields of the request message to be used for batching, and, optionally, the fields of the response message to be used for demultiplexing. -
#thresholds ⇒ Google::Apis::ServicemanagementV1::BatchingSettingsProto
BatchingSettingsProtospecifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchingConfigProto
constructor
A new instance of BatchingConfigProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchingConfigProto
Returns a new instance of BatchingConfigProto.
607 608 609 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_descriptor ⇒ Google::Apis::ServicemanagementV1::BatchingDescriptorProto
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Corresponds to the JSON property batchDescriptor
598 599 600 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 598 def batch_descriptor @batch_descriptor end |
#thresholds ⇒ Google::Apis::ServicemanagementV1::BatchingSettingsProto
BatchingSettingsProto specifies a set of batching thresholds, each of which
acts as a trigger to send a batch of messages as a request. At least one
threshold must be positive nonzero.
Corresponds to the JSON property thresholds
605 606 607 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 605 def thresholds @thresholds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
612 613 614 615 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 612 def update!(**args) @batch_descriptor = args[:batch_descriptor] if args.key?(:batch_descriptor) @thresholds = args[:thresholds] if args.key?(:thresholds) end |