Class: Google::Apis::ServicemanagementV1::BatchingDescriptorProto
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::BatchingDescriptorProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
BatchingDescriptorProto specifies the fields of the request message to be
used for batching, and, optionally, the fields of the response message to be
used for demultiplexing.
Instance Attribute Summary collapse
-
#batched_field ⇒ String
The repeated field in the request message to be aggregated by batching.
-
#discriminator_fields ⇒ Array<String>
A list of the fields in the request message.
-
#subresponse_field ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BatchingDescriptorProto
constructor
A new instance of BatchingDescriptorProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BatchingDescriptorProto
Returns a new instance of BatchingDescriptorProto.
608 609 610 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 608 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batched_field ⇒ String
The repeated field in the request message to be aggregated by batching.
Corresponds to the JSON property batchedField
592 593 594 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 592 def batched_field @batched_field end |
#discriminator_fields ⇒ Array<String>
A list of the fields in the request message. Two requests will be batched
together only if the values of every field specified in
request_discriminator_fields is equal between the two requests.
Corresponds to the JSON property discriminatorFields
599 600 601 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 599 def discriminator_fields @discriminator_fields end |
#subresponse_field ⇒ String
Optional. When present, indicates the field in the response message to be used
to demultiplex the response into multiple response messages, in correspondence
with the multiple request messages originally batched together.
Corresponds to the JSON property subresponseField
606 607 608 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 606 def subresponse_field @subresponse_field end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
613 614 615 616 617 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 613 def update!(**args) @batched_field = args[:batched_field] if args.key?(:batched_field) @discriminator_fields = args[:discriminator_fields] if args.key?(:discriminator_fields) @subresponse_field = args[:subresponse_field] if args.key?(:subresponse_field) end |