Class: Google::Apis::ServicemanagementV1::BatchingSettingsProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

BatchingSettingsProto specifies a set of batching thresholds, each of which acts as a trigger to send a batch of messages as a request. At least one threshold must be positive nonzero.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BatchingSettingsProto

Returns a new instance of BatchingSettingsProto.



671
672
673
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delay_thresholdString

The duration after which a batch should be sent, starting from the addition of the first message to that batch. Corresponds to the JSON property delayThreshold

Returns:

  • (String)


630
631
632
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 630

def delay_threshold
  @delay_threshold
end

#element_count_limitFixnum

The maximum number of elements collected in a batch that could be accepted by server. Corresponds to the JSON property elementCountLimit

Returns:

  • (Fixnum)


636
637
638
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 636

def element_count_limit
  @element_count_limit
end

#element_count_thresholdFixnum

The number of elements of a field collected into a batch which, if exceeded, causes the batch to be sent. Corresponds to the JSON property elementCountThreshold

Returns:

  • (Fixnum)


642
643
644
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 642

def element_count_threshold
  @element_count_threshold
end

#flow_control_byte_limitFixnum

The maximum size of data allowed by flow control. Corresponds to the JSON property flowControlByteLimit

Returns:

  • (Fixnum)


647
648
649
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 647

def flow_control_byte_limit
  @flow_control_byte_limit
end

#flow_control_element_limitFixnum

The maximum number of elements allowed by flow control. Corresponds to the JSON property flowControlElementLimit

Returns:

  • (Fixnum)


652
653
654
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 652

def flow_control_element_limit
  @flow_control_element_limit
end

#flow_control_limit_exceeded_behaviorString

The behavior to take when the flow control limit is exceeded. Corresponds to the JSON property flowControlLimitExceededBehavior

Returns:

  • (String)


657
658
659
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 657

def flow_control_limit_exceeded_behavior
  @flow_control_limit_exceeded_behavior
end

#request_byte_limitFixnum

The maximum size of the request that could be accepted by server. Corresponds to the JSON property requestByteLimit

Returns:

  • (Fixnum)


662
663
664
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 662

def request_byte_limit
  @request_byte_limit
end

#request_byte_thresholdFixnum

The aggregated size of the batched field which, if exceeded, causes the batch to be sent. This size is computed by aggregating the sizes of the request field to be batched, not of the entire request message. Corresponds to the JSON property requestByteThreshold

Returns:

  • (Fixnum)


669
670
671
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 669

def request_byte_threshold
  @request_byte_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



676
677
678
679
680
681
682
683
684
685
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 676

def update!(**args)
  @delay_threshold = args[:delay_threshold] if args.key?(:delay_threshold)
  @element_count_limit = args[:element_count_limit] if args.key?(:element_count_limit)
  @element_count_threshold = args[:element_count_threshold] if args.key?(:element_count_threshold)
  @flow_control_byte_limit = args[:flow_control_byte_limit] if args.key?(:flow_control_byte_limit)
  @flow_control_element_limit = args[:flow_control_element_limit] if args.key?(:flow_control_element_limit)
  @flow_control_limit_exceeded_behavior = args[:flow_control_limit_exceeded_behavior] if args.key?(:flow_control_limit_exceeded_behavior)
  @request_byte_limit = args[:request_byte_limit] if args.key?(:request_byte_limit)
  @request_byte_threshold = args[:request_byte_threshold] if args.key?(:request_byte_threshold)
end