Class: Google::Apis::ServicemanagementV1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



973
974
975
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServicemanagementV1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



917
918
919
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 917

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServicemanagementV1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



922
923
924
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 922

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServicemanagementV1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



927
928
929
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 927

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServicemanagementV1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



932
933
934
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 932

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


937
938
939
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 937

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServicemanagementV1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



942
943
944
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 942

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServicemanagementV1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



947
948
949
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 947

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServicemanagementV1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



952
953
954
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 952

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


958
959
960
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 958

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServicemanagementV1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



964
965
966
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 964

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


971
972
973
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 971

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



978
979
980
981
982
983
984
985
986
987
988
989
990
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 978

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end