Class: Google::Apis::ServicemanagementV1::ClientLibrarySettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Details about how and where to publish client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClientLibrarySettings

Returns a new instance of ClientLibrarySettings.



940
941
942
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpp_settingsGoogle::Apis::ServicemanagementV1::CppSettings

Settings for C++ client libraries. Corresponds to the JSON property cppSettings



884
885
886
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 884

def cpp_settings
  @cpp_settings
end

#dotnet_settingsGoogle::Apis::ServicemanagementV1::DotnetSettings

Settings for Dotnet client libraries. Corresponds to the JSON property dotnetSettings



889
890
891
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 889

def dotnet_settings
  @dotnet_settings
end

#go_settingsGoogle::Apis::ServicemanagementV1::GoSettings

Settings for Go client libraries. Corresponds to the JSON property goSettings



894
895
896
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 894

def go_settings
  @go_settings
end

#java_settingsGoogle::Apis::ServicemanagementV1::JavaSettings

Settings for Java client libraries. Corresponds to the JSON property javaSettings



899
900
901
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 899

def java_settings
  @java_settings
end

#launch_stageString

Launch stage of this version of the API. Corresponds to the JSON property launchStage

Returns:

  • (String)


904
905
906
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 904

def launch_stage
  @launch_stage
end

#node_settingsGoogle::Apis::ServicemanagementV1::NodeSettings

Settings for Node client libraries. Corresponds to the JSON property nodeSettings



909
910
911
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 909

def node_settings
  @node_settings
end

#php_settingsGoogle::Apis::ServicemanagementV1::PhpSettings

Settings for Php client libraries. Corresponds to the JSON property phpSettings



914
915
916
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 914

def php_settings
  @php_settings
end

#python_settingsGoogle::Apis::ServicemanagementV1::PythonSettings

Settings for Python client libraries. Corresponds to the JSON property pythonSettings



919
920
921
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 919

def python_settings
  @python_settings
end

#rest_numeric_enumsBoolean Also known as: rest_numeric_enums?

When using transport=rest, the client request will encode enums as numbers rather than strings. Corresponds to the JSON property restNumericEnums

Returns:

  • (Boolean)


925
926
927
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 925

def rest_numeric_enums
  @rest_numeric_enums
end

#ruby_settingsGoogle::Apis::ServicemanagementV1::RubySettings

Settings for Ruby client libraries. Corresponds to the JSON property rubySettings



931
932
933
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 931

def ruby_settings
  @ruby_settings
end

#versionString

Version of the API to apply these settings to. This is the full protobuf package for the API, ending in the version element. Examples: "google.cloud. speech.v1" and "google.spanner.admin.database.v1". Corresponds to the JSON property version

Returns:

  • (String)


938
939
940
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 938

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



945
946
947
948
949
950
951
952
953
954
955
956
957
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 945

def update!(**args)
  @cpp_settings = args[:cpp_settings] if args.key?(:cpp_settings)
  @dotnet_settings = args[:dotnet_settings] if args.key?(:dotnet_settings)
  @go_settings = args[:go_settings] if args.key?(:go_settings)
  @java_settings = args[:java_settings] if args.key?(:java_settings)
  @launch_stage = args[:launch_stage] if args.key?(:launch_stage)
  @node_settings = args[:node_settings] if args.key?(:node_settings)
  @php_settings = args[:php_settings] if args.key?(:php_settings)
  @python_settings = args[:python_settings] if args.key?(:python_settings)
  @rest_numeric_enums = args[:rest_numeric_enums] if args.key?(:rest_numeric_enums)
  @ruby_settings = args[:ruby_settings] if args.key?(:ruby_settings)
  @version = args[:version] if args.key?(:version)
end