Class: Google::Apis::ServicemanagementV1::ConfigChange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Output generated from semantically comparing two versions of a service configuration. Includes detailed information about a field that have changed with applicable advice about potential consequences for the change, such as backwards-incompatibility.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigChange

Returns a new instance of ConfigChange.



1067
1068
1069
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1067

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advicesArray<Google::Apis::ServicemanagementV1::Advice>

Collection of advice provided for this change, useful for determining the possible impact of this change. Corresponds to the JSON property advices



1037
1038
1039
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1037

def advices
  @advices
end

#change_typeString

The type for this change, either ADDED, REMOVED, or MODIFIED. Corresponds to the JSON property changeType

Returns:

  • (String)


1042
1043
1044
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1042

def change_type
  @change_type
end

#elementString

Object hierarchy path to the change, with levels separated by a '.' character. For repeated fields, an applicable unique identifier field is used for the index (usually selector, name, or id). For maps, the term 'key' is used. If the field has no unique identifier, the numeric index is used. Examples: - visibility.rules[selector=="google.LibraryService.ListBooks"].restriction - quota.metric_rules[selector=="google"].metric_costs[key=="reads"].value - logging.producer_destinations[0] Corresponds to the JSON property element

Returns:

  • (String)


1053
1054
1055
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1053

def element
  @element
end

#new_valueString

Value of the changed object in the new Service configuration, in JSON format. This field will not be populated if ChangeType == REMOVED. Corresponds to the JSON property newValue

Returns:

  • (String)


1059
1060
1061
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1059

def new_value
  @new_value
end

#old_valueString

Value of the changed object in the old Service configuration, in JSON format. This field will not be populated if ChangeType == ADDED. Corresponds to the JSON property oldValue

Returns:

  • (String)


1065
1066
1067
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1065

def old_value
  @old_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1072
1073
1074
1075
1076
1077
1078
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1072

def update!(**args)
  @advices = args[:advices] if args.key?(:advices)
  @change_type = args[:change_type] if args.key?(:change_type)
  @element = args[:element] if args.key?(:element)
  @new_value = args[:new_value] if args.key?(:new_value)
  @old_value = args[:old_value] if args.key?(:old_value)
end