Class: Google::Apis::ServicemanagementV1::ConfigChange
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::ConfigChange
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Output generated from semantically comparing two versions of a service configuration. Includes detailed information about a field that have changed with applicable advice about potential consequences for the change, such as backwards-incompatibility.
Instance Attribute Summary collapse
-
#advices ⇒ Array<Google::Apis::ServicemanagementV1::Advice>
Collection of advice provided for this change, useful for determining the possible impact of this change.
-
#change_type ⇒ String
The type for this change, either ADDED, REMOVED, or MODIFIED.
-
#element ⇒ String
Object hierarchy path to the change, with levels separated by a '.' character.
-
#new_value ⇒ String
Value of the changed object in the new Service configuration, in JSON format.
-
#old_value ⇒ String
Value of the changed object in the old Service configuration, in JSON format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigChange
constructor
A new instance of ConfigChange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigChange
Returns a new instance of ConfigChange.
1034 1035 1036 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1034 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advices ⇒ Array<Google::Apis::ServicemanagementV1::Advice>
Collection of advice provided for this change, useful for determining the
possible impact of this change.
Corresponds to the JSON property advices
1004 1005 1006 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1004 def advices @advices end |
#change_type ⇒ String
The type for this change, either ADDED, REMOVED, or MODIFIED.
Corresponds to the JSON property changeType
1009 1010 1011 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1009 def change_type @change_type end |
#element ⇒ String
Object hierarchy path to the change, with levels separated by a '.' character.
For repeated fields, an applicable unique identifier field is used for the
index (usually selector, name, or id). For maps, the term 'key' is used. If
the field has no unique identifier, the numeric index is used. Examples: -
visibility.rules[selector=="google.LibraryService.ListBooks"].restriction -
quota.metric_rules[selector=="google"].metric_costs[key=="reads"].value -
logging.producer_destinations[0]
Corresponds to the JSON property element
1020 1021 1022 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1020 def element @element end |
#new_value ⇒ String
Value of the changed object in the new Service configuration, in JSON format.
This field will not be populated if ChangeType == REMOVED.
Corresponds to the JSON property newValue
1026 1027 1028 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1026 def new_value @new_value end |
#old_value ⇒ String
Value of the changed object in the old Service configuration, in JSON format.
This field will not be populated if ChangeType == ADDED.
Corresponds to the JSON property oldValue
1032 1033 1034 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1032 def old_value @old_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1039 1040 1041 1042 1043 1044 1045 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1039 def update!(**args) @advices = args[:advices] if args.key?(:advices) @change_type = args[:change_type] if args.key?(:change_type) @element = args[:element] if args.key?(:element) @new_value = args[:new_value] if args.key?(:new_value) @old_value = args[:old_value] if args.key?(:old_value) end |