Class: Google::Apis::ServicemanagementV1::ConfigSource
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::ConfigSource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Represents a source file which is used to generate the service configuration
defined by google.api.Service.
Instance Attribute Summary collapse
-
#files ⇒ Array<Google::Apis::ServicemanagementV1::ConfigFile>
Set of source configuration files that are used to generate a service configuration (
google.api.Service). -
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the client for tracking purpose.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigSource
constructor
A new instance of ConfigSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigSource
Returns a new instance of ConfigSource.
1118 1119 1120 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#files ⇒ Array<Google::Apis::ServicemanagementV1::ConfigFile>
Set of source configuration files that are used to generate a service
configuration (google.api.Service).
Corresponds to the JSON property files
1109 1110 1111 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1109 def files @files end |
#id ⇒ String
A unique ID for a specific instance of this message, typically assigned by the
client for tracking purpose. If empty, the server may choose to generate one
instead.
Corresponds to the JSON property id
1116 1117 1118 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1116 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1123 1124 1125 1126 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1123 def update!(**args) @files = args[:files] if args.key?(:files) @id = args[:id] if args.key?(:id) end |