Class: Google::Apis::ServicemanagementV1::ContextRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::ContextRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
A context rule provides information about the context for an individual API element.
Instance Attribute Summary collapse
-
#allowed_request_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from client to backend.
-
#allowed_response_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side channel from backend to client.
-
#provided ⇒ Array<String>
A list of full type names of provided contexts.
-
#requested ⇒ Array<String>
A list of full type names of requested contexts, only the requested context will be made available to the backend.
-
#selector ⇒ String
Selects the methods to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContextRule
constructor
A new instance of ContextRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContextRule
Returns a new instance of ContextRule.
1196 1197 1198 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_request_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side
channel from client to backend.
Corresponds to the JSON property allowedRequestExtensions
1170 1171 1172 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1170 def allowed_request_extensions @allowed_request_extensions end |
#allowed_response_extensions ⇒ Array<String>
A list of full type names or extension IDs of extensions allowed in grpc side
channel from backend to client.
Corresponds to the JSON property allowedResponseExtensions
1176 1177 1178 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1176 def allowed_response_extensions @allowed_response_extensions end |
#provided ⇒ Array<String>
A list of full type names of provided contexts. It is used to support
propagating HTTP headers and ETags from the response extension.
Corresponds to the JSON property provided
1182 1183 1184 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1182 def provided @provided end |
#requested ⇒ Array<String>
A list of full type names of requested contexts, only the requested context
will be made available to the backend.
Corresponds to the JSON property requested
1188 1189 1190 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1188 def requested @requested end |
#selector ⇒ String
Selects the methods to which this rule applies. Refer to selector for syntax
details.
Corresponds to the JSON property selector
1194 1195 1196 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1194 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1201 1202 1203 1204 1205 1206 1207 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1201 def update!(**args) @allowed_request_extensions = args[:allowed_request_extensions] if args.key?(:allowed_request_extensions) @allowed_response_extensions = args[:allowed_response_extensions] if args.key?(:allowed_response_extensions) @provided = args[:provided] if args.key?(:provided) @requested = args[:requested] if args.key?(:requested) @selector = args[:selector] if args.key?(:selector) end |