Class: Google::Apis::ServicemanagementV1::Enum
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Enum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#enumvalue ⇒ Array<Google::Apis::ServicemanagementV1::EnumValue>
Enum value definitions.
-
#name ⇒ String
Enum type name.
-
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
Protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Enum
constructor
A new instance of Enum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Enum
Returns a new instance of Enum.
1734 1735 1736 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
1706 1707 1708 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1706 def edition @edition end |
#enumvalue ⇒ Array<Google::Apis::ServicemanagementV1::EnumValue>
Enum value definitions.
Corresponds to the JSON property enumvalue
1711 1712 1713 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1711 def enumvalue @enumvalue end |
#name ⇒ String
Enum type name.
Corresponds to the JSON property name
1716 1717 1718 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1716 def name @name end |
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
Protocol buffer options.
Corresponds to the JSON property options
1721 1722 1723 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1721 def @options end |
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
1727 1728 1729 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1727 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
1732 1733 1734 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1732 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1739 1740 1741 1742 1743 1744 1745 1746 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1739 def update!(**args) @edition = args[:edition] if args.key?(:edition) @enumvalue = args[:enumvalue] if args.key?(:enumvalue) @name = args[:name] if args.key?(:name) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |