Class: Google::Apis::ServicemanagementV1::Enum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enum

Returns a new instance of Enum.



1731
1732
1733
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1731

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


1703
1704
1705
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1703

def edition
  @edition
end

#enumvalueArray<Google::Apis::ServicemanagementV1::EnumValue>

Enum value definitions. Corresponds to the JSON property enumvalue



1708
1709
1710
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1708

def enumvalue
  @enumvalue
end

#nameString

Enum type name. Corresponds to the JSON property name

Returns:

  • (String)


1713
1714
1715
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1713

def name
  @name
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1718
1719
1720
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1718

def options
  @options
end

#source_contextGoogle::Apis::ServicemanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



1724
1725
1726
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1724

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


1729
1730
1731
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1729

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1736
1737
1738
1739
1740
1741
1742
1743
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1736

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @enumvalue = args[:enumvalue] if args.key?(:enumvalue)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end