Class: Google::Apis::ServicemanagementV1::Enum

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Enum type definition. New usages of this message as an alternative to EnumDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Enum

Returns a new instance of Enum.



1698
1699
1700
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1698

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


1670
1671
1672
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1670

def edition
  @edition
end

#enumvalueArray<Google::Apis::ServicemanagementV1::EnumValue>

Enum value definitions. Corresponds to the JSON property enumvalue



1675
1676
1677
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1675

def enumvalue
  @enumvalue
end

#nameString

Enum type name. Corresponds to the JSON property name

Returns:

  • (String)


1680
1681
1682
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1680

def name
  @name
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1685
1686
1687
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1685

def options
  @options
end

#source_contextGoogle::Apis::ServicemanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



1691
1692
1693
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1691

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


1696
1697
1698
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1696

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1703
1704
1705
1706
1707
1708
1709
1710
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1703

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @enumvalue = args[:enumvalue] if args.key?(:enumvalue)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end