Class: Google::Apis::ServicemanagementV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1769
1770
1771
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1757

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1762
1763
1764
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1762

def number
  @number
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1767
1768
1769
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1767

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1774
1775
1776
1777
1778
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1774

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end