Class: Google::Apis::ServicemanagementV1::EnumValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Enum value definition. New usages of this message as an alternative to EnumValueDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EnumValue

Returns a new instance of EnumValue.



1736
1737
1738
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Enum value name. Corresponds to the JSON property name

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1724

def name
  @name
end

#numberFixnum

Enum value number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1729
1730
1731
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1729

def number
  @number
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

Protocol buffer options. Corresponds to the JSON property options



1734
1735
1736
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1734

def options
  @options
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1741
1742
1743
1744
1745
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1741

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @options = args[:options] if args.key?(:options)
end