Class: Google::Apis::ServicemanagementV1::ExperimentalFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::ExperimentalFeatures
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default.
Instance Attribute Summary collapse
-
#protobuf_pythonic_types_enabled ⇒ Boolean
(also: #protobuf_pythonic_types_enabled?)
Enables generation of protobuf code using new types that are more Pythonic which are included in
protobuf>=5.29.x. -
#rest_async_io_enabled ⇒ Boolean
(also: #rest_async_io_enabled?)
Enables generation of asynchronous REST clients if
resttransport is enabled. -
#unversioned_package_disabled ⇒ Boolean
(also: #unversioned_package_disabled?)
Disables generation of an unversioned Python package for this client library.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExperimentalFeatures
constructor
A new instance of ExperimentalFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExperimentalFeatures
Returns a new instance of ExperimentalFeatures.
1779 1780 1781 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#protobuf_pythonic_types_enabled ⇒ Boolean Also known as: protobuf_pythonic_types_enabled?
Enables generation of protobuf code using new types that are more Pythonic
which are included in protobuf>=5.29.x. This feature will be enabled by
default 1 month after launching the feature in preview packages.
Corresponds to the JSON property protobufPythonicTypesEnabled
1758 1759 1760 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1758 def protobuf_pythonic_types_enabled @protobuf_pythonic_types_enabled end |
#rest_async_io_enabled ⇒ Boolean Also known as: rest_async_io_enabled?
Enables generation of asynchronous REST clients if rest transport is enabled.
By default, asynchronous REST clients will not be generated. This feature
will be enabled by default 1 month after launching the feature in preview
packages.
Corresponds to the JSON property restAsyncIoEnabled
1767 1768 1769 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1767 def rest_async_io_enabled @rest_async_io_enabled end |
#unversioned_package_disabled ⇒ Boolean Also known as: unversioned_package_disabled?
Disables generation of an unversioned Python package for this client library.
This means that the module names will need to be versioned in import
statements. For example import google.cloud.library_v2 instead of import
google.cloud.library.
Corresponds to the JSON property unversionedPackageDisabled
1776 1777 1778 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1776 def unversioned_package_disabled @unversioned_package_disabled end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1784 1785 1786 1787 1788 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1784 def update!(**args) @protobuf_pythonic_types_enabled = args[:protobuf_pythonic_types_enabled] if args.key?(:protobuf_pythonic_types_enabled) @rest_async_io_enabled = args[:rest_async_io_enabled] if args.key?(:rest_async_io_enabled) @unversioned_package_disabled = args[:unversioned_package_disabled] if args.key?(:unversioned_package_disabled) end |