Class: Google::Apis::ServicemanagementV1::Field
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Field
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#cardinality ⇒ String
The field cardinality.
-
#default_value ⇒ String
The string value of the default value of this field.
-
#json_name ⇒ String
The field JSON name.
-
#kind ⇒ String
The field type.
-
#name ⇒ String
The field name.
-
#number ⇒ Fixnum
The field number.
-
#oneof_index ⇒ Fixnum
The index of the field type in
Type.oneofs, for message or enumeration types. -
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
-
#packed ⇒ Boolean
(also: #packed?)
Whether to use alternative packed wire representation.
-
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
1939 1940 1941 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1939 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cardinality ⇒ String
The field cardinality.
Corresponds to the JSON property cardinality
1889 1890 1891 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1889 def cardinality @cardinality end |
#default_value ⇒ String
The string value of the default value of this field. Proto2 syntax only.
Corresponds to the JSON property defaultValue
1894 1895 1896 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1894 def default_value @default_value end |
#json_name ⇒ String
The field JSON name.
Corresponds to the JSON property jsonName
1899 1900 1901 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1899 def json_name @json_name end |
#kind ⇒ String
The field type.
Corresponds to the JSON property kind
1904 1905 1906 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1904 def kind @kind end |
#name ⇒ String
The field name.
Corresponds to the JSON property name
1909 1910 1911 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1909 def name @name end |
#number ⇒ Fixnum
The field number.
Corresponds to the JSON property number
1914 1915 1916 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1914 def number @number end |
#oneof_index ⇒ Fixnum
The index of the field type in Type.oneofs, for message or enumeration types.
The first type has index 1; zero means the type is not in the list.
Corresponds to the JSON property oneofIndex
1920 1921 1922 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1920 def oneof_index @oneof_index end |
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
1925 1926 1927 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1925 def @options end |
#packed ⇒ Boolean Also known as: packed?
Whether to use alternative packed wire representation.
Corresponds to the JSON property packed
1930 1931 1932 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1930 def packed @packed end |
#type_url ⇒ String
The field type URL, without the scheme, for message or enumeration types.
Example: "type.googleapis.com/google.protobuf.Timestamp".
Corresponds to the JSON property typeUrl
1937 1938 1939 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1937 def type_url @type_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1944 1945 1946 1947 1948 1949 1950 1951 1952 1953 1954 1955 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1944 def update!(**args) @cardinality = args[:cardinality] if args.key?(:cardinality) @default_value = args[:default_value] if args.key?(:default_value) @json_name = args[:json_name] if args.key?(:json_name) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @number = args[:number] if args.key?(:number) @oneof_index = args[:oneof_index] if args.key?(:oneof_index) @options = args[:options] if args.key?(:options) @packed = args[:packed] if args.key?(:packed) @type_url = args[:type_url] if args.key?(:type_url) end |