Class: Google::Apis::ServicemanagementV1::Field

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

A single field of a message type. New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Field

Returns a new instance of Field.



1906
1907
1908
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cardinalityString

The field cardinality. Corresponds to the JSON property cardinality

Returns:

  • (String)


1856
1857
1858
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1856

def cardinality
  @cardinality
end

#default_valueString

The string value of the default value of this field. Proto2 syntax only. Corresponds to the JSON property defaultValue

Returns:

  • (String)


1861
1862
1863
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1861

def default_value
  @default_value
end

#json_nameString

The field JSON name. Corresponds to the JSON property jsonName

Returns:

  • (String)


1866
1867
1868
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1866

def json_name
  @json_name
end

#kindString

The field type. Corresponds to the JSON property kind

Returns:

  • (String)


1871
1872
1873
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1871

def kind
  @kind
end

#nameString

The field name. Corresponds to the JSON property name

Returns:

  • (String)


1876
1877
1878
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1876

def name
  @name
end

#numberFixnum

The field number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


1881
1882
1883
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1881

def number
  @number
end

#oneof_indexFixnum

The index of the field type in Type.oneofs, for message or enumeration types. The first type has index 1; zero means the type is not in the list. Corresponds to the JSON property oneofIndex

Returns:

  • (Fixnum)


1887
1888
1889
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1887

def oneof_index
  @oneof_index
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



1892
1893
1894
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1892

def options
  @options
end

#packedBoolean Also known as: packed?

Whether to use alternative packed wire representation. Corresponds to the JSON property packed

Returns:

  • (Boolean)


1897
1898
1899
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1897

def packed
  @packed
end

#type_urlString

The field type URL, without the scheme, for message or enumeration types. Example: "type.googleapis.com/google.protobuf.Timestamp". Corresponds to the JSON property typeUrl

Returns:

  • (String)


1904
1905
1906
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1904

def type_url
  @type_url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1911
1912
1913
1914
1915
1916
1917
1918
1919
1920
1921
1922
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1911

def update!(**args)
  @cardinality = args[:cardinality] if args.key?(:cardinality)
  @default_value = args[:default_value] if args.key?(:default_value)
  @json_name = args[:json_name] if args.key?(:json_name)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @number = args[:number] if args.key?(:number)
  @oneof_index = args[:oneof_index] if args.key?(:oneof_index)
  @options = args[:options] if args.key?(:options)
  @packed = args[:packed] if args.key?(:packed)
  @type_url = args[:type_url] if args.key?(:type_url)
end