Class: Google::Apis::ServicemanagementV1::FieldPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::FieldPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Google API Policy Annotation This message defines a simple API policy annotation that can be used to annotate API request and response message fields with applicable policies. One field may have multiple applicable policies that must all be satisfied before a request can be processed. This policy annotation is used to generate the overall policy that will be used for automatic runtime policy enforcement and documentation generation.
Instance Attribute Summary collapse
-
#resource_permission ⇒ String
Specifies the required permission(s) for the resource referred to by the field.
-
#resource_type ⇒ String
Specifies the resource type for the resource referred to by the field.
-
#selector ⇒ String
Selects one or more request or response message fields to apply this
FieldPolicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FieldPolicy
constructor
A new instance of FieldPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FieldPolicy
Returns a new instance of FieldPolicy.
1990 1991 1992 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_permission ⇒ String
Specifies the required permission(s) for the resource referred to by the field.
It requires the field contains a valid resource reference, and the request
must pass the permission checks to proceed. For example, "resourcemanager.
projects.get".
Corresponds to the JSON property resourcePermission
1973 1974 1975 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1973 def @resource_permission end |
#resource_type ⇒ String
Specifies the resource type for the resource referred to by the field.
Corresponds to the JSON property resourceType
1978 1979 1980 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1978 def resource_type @resource_type end |
#selector ⇒ String
Selects one or more request or response message fields to apply this
FieldPolicy. When a FieldPolicy is used in proto annotation, the selector
must be left as empty. The service config generator will automatically fill
the correct value. When a FieldPolicy is used in service config, the
selector must be a comma-separated string with valid request or response field
paths, such as "foo.bar" or "foo.bar,foo.baz".
Corresponds to the JSON property selector
1988 1989 1990 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1988 def selector @selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1995 1996 1997 1998 1999 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 1995 def update!(**args) @resource_permission = args[:resource_permission] if args.key?(:resource_permission) @resource_type = args[:resource_type] if args.key?(:resource_type) @selector = args[:selector] if args.key?(:selector) end |