Class: Google::Apis::ServicemanagementV1::GenerateConfigReportRequest
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::GenerateConfigReportRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Request message for GenerateConfigReport method.
Instance Attribute Summary collapse
-
#new_config ⇒ Hash<String,Object>
Required.
-
#old_config ⇒ Hash<String,Object>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateConfigReportRequest
constructor
A new instance of GenerateConfigReportRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateConfigReportRequest
Returns a new instance of GenerateConfigReportRequest.
2015 2016 2017 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2015 def initialize(**args) update!(**args) end |
Instance Attribute Details
#new_config ⇒ Hash<String,Object>
Required. Service configuration for which we want to generate the report. For
this version of API, the supported types are google.api.servicemanagement.v1.
ConfigRef, google.api.servicemanagement.v1.ConfigSource, and google.api.
Service
Corresponds to the JSON property newConfig
2005 2006 2007 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2005 def new_config @new_config end |
#old_config ⇒ Hash<String,Object>
Optional. Service configuration against which the comparison will be done. For
this version of API, the supported types are google.api.servicemanagement.v1.
ConfigRef, google.api.servicemanagement.v1.ConfigSource, and google.api.
Service
Corresponds to the JSON property oldConfig
2013 2014 2015 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2013 def old_config @old_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2020 2021 2022 2023 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2020 def update!(**args) @new_config = args[:new_config] if args.key?(:new_config) @old_config = args[:old_config] if args.key?(:old_config) end |