Class: Google::Apis::ServicemanagementV1::GenerateConfigReportResponse
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::GenerateConfigReportResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Response message for GenerateConfigReport method.
Instance Attribute Summary collapse
-
#change_reports ⇒ Array<Google::Apis::ServicemanagementV1::ChangeReport>
list of ChangeReport, each corresponding to comparison between two service configurations.
-
#diagnostics ⇒ Array<Google::Apis::ServicemanagementV1::Diagnostic>
Errors / Linter warnings associated with the service definition this report belongs to.
-
#id ⇒ String
ID of the service configuration this report belongs to.
-
#service_name ⇒ String
Name of the service this report belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateConfigReportResponse
constructor
A new instance of GenerateConfigReportResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateConfigReportResponse
Returns a new instance of GenerateConfigReportResponse.
2052 2053 2054 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2052 def initialize(**args) update!(**args) end |
Instance Attribute Details
#change_reports ⇒ Array<Google::Apis::ServicemanagementV1::ChangeReport>
list of ChangeReport, each corresponding to comparison between two service
configurations.
Corresponds to the JSON property changeReports
2034 2035 2036 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2034 def change_reports @change_reports end |
#diagnostics ⇒ Array<Google::Apis::ServicemanagementV1::Diagnostic>
Errors / Linter warnings associated with the service definition this report
belongs to.
Corresponds to the JSON property diagnostics
2040 2041 2042 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2040 def diagnostics @diagnostics end |
#id ⇒ String
ID of the service configuration this report belongs to.
Corresponds to the JSON property id
2045 2046 2047 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2045 def id @id end |
#service_name ⇒ String
Name of the service this report belongs to.
Corresponds to the JSON property serviceName
2050 2051 2052 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2050 def service_name @service_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2057 2058 2059 2060 2061 2062 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2057 def update!(**args) @change_reports = args[:change_reports] if args.key?(:change_reports) @diagnostics = args[:diagnostics] if args.key?(:diagnostics) @id = args[:id] if args.key?(:id) @service_name = args[:service_name] if args.key?(:service_name) end |