Class: Google::Apis::ServicemanagementV1::JwtLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Specifies a location to extract JWT from an API request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JwtLocation

Returns a new instance of JwtLocation.



2452
2453
2454
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Specifies cookie name to extract JWT token. Corresponds to the JSON property cookie

Returns:

  • (String)


2430
2431
2432
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2430

def cookie
  @cookie
end

#headerString

Specifies HTTP header name to extract JWT token. Corresponds to the JSON property header

Returns:

  • (String)


2435
2436
2437
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2435

def header
  @header
end

#queryString

Specifies URL query parameter name to extract JWT token. Corresponds to the JSON property query

Returns:

  • (String)


2440
2441
2442
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2440

def query
  @query
end

#value_prefixString

The value prefix. The value format is "value_prefixtoken" Only applies to " in" header type. Must be empty for "in" query type. If not empty, the header value has to match (case sensitive) this prefix. If not matched, JWT will not be extracted. If matched, JWT will be extracted after the prefix is removed. For example, for "Authorization: Bearer JWT", value_prefix="Bearer " with a space at the end. Corresponds to the JSON property valuePrefix

Returns:

  • (String)


2450
2451
2452
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2450

def value_prefix
  @value_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2457
2458
2459
2460
2461
2462
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2457

def update!(**args)
  @cookie = args[:cookie] if args.key?(:cookie)
  @header = args[:header] if args.key?(:header)
  @query = args[:query] if args.key?(:query)
  @value_prefix = args[:value_prefix] if args.key?(:value_prefix)
end