Class: Google::Apis::ServicemanagementV1::MethodProp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Method represents a method of an API interface. New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodProp

Returns a new instance of MethodProp.



2842
2843
2844
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. This field should be ignored, instead the edition should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property edition

Returns:

  • (String)


2802
2803
2804
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2802

def edition
  @edition
end

#nameString

The simple name of this method. Corresponds to the JSON property name

Returns:

  • (String)


2807
2808
2809
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2807

def name
  @name
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

Any metadata attached to the method. Corresponds to the JSON property options



2812
2813
2814
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2812

def options
  @options
end

#request_streamingBoolean Also known as: request_streaming?

If true, the request is streamed. Corresponds to the JSON property requestStreaming

Returns:

  • (Boolean)


2817
2818
2819
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2817

def request_streaming
  @request_streaming
end

#request_type_urlString

A URL of the input message type. Corresponds to the JSON property requestTypeUrl

Returns:

  • (String)


2823
2824
2825
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2823

def request_type_url
  @request_type_url
end

#response_streamingBoolean Also known as: response_streaming?

If true, the response is streamed. Corresponds to the JSON property responseStreaming

Returns:

  • (Boolean)


2828
2829
2830
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2828

def response_streaming
  @response_streaming
end

#response_type_urlString

The URL of the output message type. Corresponds to the JSON property responseTypeUrl

Returns:

  • (String)


2834
2835
2836
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2834

def response_type_url
  @response_type_url
end

#syntaxString

The source syntax of this method. This field should be ignored, instead the syntax should be inherited from Api. This is similar to Field and EnumValue. Corresponds to the JSON property syntax

Returns:

  • (String)


2840
2841
2842
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2840

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2847

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @request_streaming = args[:request_streaming] if args.key?(:request_streaming)
  @request_type_url = args[:request_type_url] if args.key?(:request_type_url)
  @response_streaming = args[:response_streaming] if args.key?(:response_streaming)
  @response_type_url = args[:response_type_url] if args.key?(:response_type_url)
  @syntax = args[:syntax] if args.key?(:syntax)
end