Class: Google::Apis::ServicemanagementV1::MethodSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Describes the generator configuration for a method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MethodSettings

Returns a new instance of MethodSettings.



2922
2923
2924
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_populated_fieldsArray<String>

List of top-level fields of the request message, that should be automatically populated by the client libraries based on their (google.api.field_info). format. Currently supported format: UUID4. Example of a YAML configuration: publishing: method_settings: - selector: google.example.v1.ExampleService. CreateExample auto_populated_fields: - request_id Corresponds to the JSON property autoPopulatedFields

Returns:

  • (Array<String>)


2898
2899
2900
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2898

def auto_populated_fields
  @auto_populated_fields
end

#batchingGoogle::Apis::ServicemanagementV1::BatchingConfigProto

BatchingConfigProto defines the batching configuration for an API method. Corresponds to the JSON property batching



2903
2904
2905
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2903

def batching
  @batching
end

#long_runningGoogle::Apis::ServicemanagementV1::LongRunning

Describes settings to use when generating API methods that use the long- running operation pattern. All default values below are from those used in the client library generators (e.g. Java). Corresponds to the JSON property longRunning



2912
2913
2914
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2912

def long_running
  @long_running
end

#selectorString

The fully qualified name of the method, for which the options below apply. This is used to find the method to apply the options. Example: publishing: method_settings: - selector: google.storage.control.v2.StorageControl. CreateFolder # method settings for CreateFolder... Corresponds to the JSON property selector

Returns:

  • (String)


2920
2921
2922
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2920

def selector
  @selector
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2927
2928
2929
2930
2931
2932
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 2927

def update!(**args)
  @auto_populated_fields = args[:auto_populated_fields] if args.key?(:auto_populated_fields)
  @batching = args[:batching] if args.key?(:batching)
  @long_running = args[:long_running] if args.key?(:long_running)
  @selector = args[:selector] if args.key?(:selector)
end