Class: Google::Apis::ServicemanagementV1::MetricDescriptorMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::MetricDescriptorMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Additional annotations that can be used to guide the usage of a metric.
Instance Attribute Summary collapse
-
#ingest_delay ⇒ String
The delay of data points caused by ingestion.
-
#launch_stage ⇒ String
Deprecated.
-
#sample_period ⇒ String
The sampling period of metric data points.
-
#time_series_resource_hierarchy_level ⇒ Array<String>
The scope of the timeseries data of the metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetricDescriptorMetadata
constructor
A new instance of MetricDescriptorMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetricDescriptorMetadata
Returns a new instance of MetricDescriptorMetadata.
3107 3108 3109 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingest_delay ⇒ String
The delay of data points caused by ingestion. Data points older than this age
are guaranteed to be ingested and available to be read, excluding data loss
due to errors.
Corresponds to the JSON property ingestDelay
3087 3088 3089 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3087 def ingest_delay @ingest_delay end |
#launch_stage ⇒ String
Deprecated. Must use the MetricDescriptor.launch_stage instead.
Corresponds to the JSON property launchStage
3092 3093 3094 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3092 def launch_stage @launch_stage end |
#sample_period ⇒ String
The sampling period of metric data points. For metrics which are written
periodically, consecutive data points are stored at this time interval,
excluding data loss due to errors. Metrics with a higher granularity have a
smaller sampling period.
Corresponds to the JSON property samplePeriod
3100 3101 3102 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3100 def sample_period @sample_period end |
#time_series_resource_hierarchy_level ⇒ Array<String>
The scope of the timeseries data of the metric.
Corresponds to the JSON property timeSeriesResourceHierarchyLevel
3105 3106 3107 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3105 def time_series_resource_hierarchy_level @time_series_resource_hierarchy_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3112 3113 3114 3115 3116 3117 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3112 def update!(**args) @ingest_delay = args[:ingest_delay] if args.key?(:ingest_delay) @launch_stage = args[:launch_stage] if args.key?(:launch_stage) @sample_period = args[:sample_period] if args.key?(:sample_period) @time_series_resource_hierarchy_level = args[:time_series_resource_hierarchy_level] if args.key?(:time_series_resource_hierarchy_level) end |