Class: Google::Apis::ServicemanagementV1::PythonSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

Settings for Python client libraries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PythonSettings

Returns a new instance of PythonSettings.



3883
3884
3885
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3883

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commonGoogle::Apis::ServicemanagementV1::CommonLanguageSettings

Required information for every language. Corresponds to the JSON property common



3875
3876
3877
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3875

def common
  @common
end

#experimental_featuresGoogle::Apis::ServicemanagementV1::ExperimentalFeatures

Experimental features to be included during client library generation. These fields will be deprecated once the feature graduates and is enabled by default. Corresponds to the JSON property experimentalFeatures



3881
3882
3883
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3881

def experimental_features
  @experimental_features
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3888
3889
3890
3891
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 3888

def update!(**args)
  @common = args[:common] if args.key?(:common)
  @experimental_features = args[:experimental_features] if args.key?(:experimental_features)
end