Class: Google::Apis::ServicemanagementV1::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
A rollout resource that defines how service configuration versions are pushed to control plane systems. Typically, you create a new version of the service config, and then create a Rollout to push the service config.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Creation time of the rollout.
-
#created_by ⇒ String
The user who created the Rollout.
-
#delete_service_strategy ⇒ Google::Apis::ServicemanagementV1::DeleteServiceStrategy
Strategy used to delete a service.
-
#rollout_id ⇒ String
Optional.
-
#service_name ⇒ String
The name of the service associated with this Rollout.
-
#status ⇒ String
The status of this rollout.
-
#traffic_percent_strategy ⇒ Google::Apis::ServicemanagementV1::TrafficPercentStrategy
Strategy that specifies how clients of Google Service Controller want to send traffic to use different config versions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
4137 4138 4139 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4137 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Creation time of the rollout. Readonly.
Corresponds to the JSON property createTime
4089 4090 4091 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4089 def create_time @create_time end |
#created_by ⇒ String
The user who created the Rollout. Readonly.
Corresponds to the JSON property createdBy
4094 4095 4096 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4094 def created_by @created_by end |
#delete_service_strategy ⇒ Google::Apis::ServicemanagementV1::DeleteServiceStrategy
Strategy used to delete a service. This strategy is a placeholder only used by
the system generated rollout to delete a service.
Corresponds to the JSON property deleteServiceStrategy
4100 4101 4102 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4100 def delete_service_strategy @delete_service_strategy end |
#rollout_id ⇒ String
Optional. Unique identifier of this Rollout. Must be no longer than 63
characters and only lower case letters, digits, '.', '_' and '-' are allowed.
If not specified by client, the server will generate one. The generated id
will have the form of , where "date" is the create date in ISO 8601 format. "
revision number" is a monotonically increasing positive number that is reset
every day for each service. An example of the generated rollout_id is '2016-02-
16r1'
Corresponds to the JSON property rolloutId
4111 4112 4113 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4111 def rollout_id @rollout_id end |
#service_name ⇒ String
The name of the service associated with this Rollout.
Corresponds to the JSON property serviceName
4116 4117 4118 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4116 def service_name @service_name end |
#status ⇒ String
The status of this rollout. Readonly. In case of a failed rollout, the system
will automatically rollback to the current Rollout version. Readonly.
Corresponds to the JSON property status
4122 4123 4124 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4122 def status @status end |
#traffic_percent_strategy ⇒ Google::Apis::ServicemanagementV1::TrafficPercentStrategy
Strategy that specifies how clients of Google Service Controller want to send
traffic to use different config versions. This is generally used by API proxy
to split traffic based on your configured percentage for each config version.
One example of how to gradually rollout a new service configuration using this
strategy: Day 1 Rollout id: "example.googleapis.com/rollout_20160206"
traffic_percent_strategy percentages: "example.googleapis.com/20160201":
70.00 "example.googleapis.com/20160206": 30.00 Day 2 Rollout id: "
example.googleapis.com/rollout_20160207" traffic_percent_strategy:
percentages: "example.googleapis.com/20160206": 100.00
Corresponds to the JSON property trafficPercentStrategy
4135 4136 4137 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4135 def traffic_percent_strategy @traffic_percent_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4142 4143 4144 4145 4146 4147 4148 4149 4150 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4142 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @created_by = args[:created_by] if args.key?(:created_by) @delete_service_strategy = args[:delete_service_strategy] if args.key?(:delete_service_strategy) @rollout_id = args[:rollout_id] if args.key?(:rollout_id) @service_name = args[:service_name] if args.key?(:service_name) @status = args[:status] if args.key?(:status) @traffic_percent_strategy = args[:traffic_percent_strategy] if args.key?(:traffic_percent_strategy) end |