Class: Google::Apis::ServicemanagementV1::SelectiveGapicGeneration
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::SelectiveGapicGeneration
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
This message is used to configure the generation of a subset of the RPCs in a service for client libraries.
Instance Attribute Summary collapse
-
#generate_omitted_as_internal ⇒ Boolean
(also: #generate_omitted_as_internal?)
Setting this to true indicates to the client generators that methods that would be excluded from the generation should instead be generated in a way that indicates these methods should not be consumed by end users.
-
#methods_prop ⇒ Array<String>
An allowlist of the fully qualified names of RPCs that should be included on public client surfaces.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SelectiveGapicGeneration
constructor
A new instance of SelectiveGapicGeneration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SelectiveGapicGeneration
Returns a new instance of SelectiveGapicGeneration.
4161 4162 4163 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4161 def initialize(**args) update!(**args) end |
Instance Attribute Details
#generate_omitted_as_internal ⇒ Boolean Also known as: generate_omitted_as_internal?
Setting this to true indicates to the client generators that methods that
would be excluded from the generation should instead be generated in a way
that indicates these methods should not be consumed by end users. How this is
expressed is up to individual language implementations to decide. Some
examples may be: added annotations, obfuscated identifiers, or other language
idiomatic patterns.
Corresponds to the JSON property generateOmittedAsInternal
4152 4153 4154 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4152 def generate_omitted_as_internal @generate_omitted_as_internal end |
#methods_prop ⇒ Array<String>
An allowlist of the fully qualified names of RPCs that should be included on
public client surfaces.
Corresponds to the JSON property methods
4159 4160 4161 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4159 def methods_prop @methods_prop end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4166 4167 4168 4169 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4166 def update!(**args) @generate_omitted_as_internal = args[:generate_omitted_as_internal] if args.key?(:generate_omitted_as_internal) @methods_prop = args[:methods_prop] if args.key?(:methods_prop) end |