Class: Google::Apis::ServicemanagementV1::ServiceManagementService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ServicemanagementV1::ServiceManagementService
- Defined in:
- lib/google/apis/servicemanagement_v1/service.rb
Overview
Service Management API
Google Service Management allows service producers to publish their services on Google Cloud Platform so that they can be discovered and used by service consumers.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://servicemanagement.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#create_service(managed_service_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new managed service.
-
#create_service_config(service_name, service_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Creates a new service configuration (version) for a managed service.
-
#create_service_rollout(service_name, rollout_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new service configuration rollout.
-
#delete_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Deletes a managed service.
-
#generate_service_config_report(generate_config_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::GenerateConfigReportResponse
Generates and returns a report (errors, warnings and changes from existing configurations) associated with GenerateConfigReportRequest.new_value If GenerateConfigReportRequest.old_value is specified, GenerateConfigReportRequest will contain a single ChangeReport based on the comparison between GenerateConfigReportRequest.new_value and GenerateConfigReportRequest.old_value.
-
#get_consumer_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Gets the access control policy for a resource.
-
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Gets the latest state of a long-running operation.
-
#get_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ManagedService
Gets a managed service.
-
#get_service_config(service_name, config_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Gets a service configuration (version) for a managed service.
-
#get_service_configuration(service_name, config_id: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Gets a service configuration (version) for a managed service.
-
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Gets the access control policy for a resource.
-
#get_service_rollout(service_name, rollout_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Rollout
Gets a service configuration rollout.
-
#initialize ⇒ ServiceManagementService
constructor
A new instance of ServiceManagementService.
-
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListOperationsResponse
Lists service operations that match the specified filter in the request.
-
#list_service_configs(service_name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServiceConfigsResponse
Lists the history of the service configuration for a managed service, from the newest to the oldest.
-
#list_service_rollouts(service_name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServiceRolloutsResponse
Lists the history of the service configuration rollouts for a managed service, from the newest to the oldest.
-
#list_services(consumer_id: nil, page_size: nil, page_token: nil, producer_project_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServicesResponse
Lists managed services.
-
#set_consumer_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Sets the access control policy on the specified resource.
-
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Sets the access control policy on the specified resource.
-
#submit_config_source(service_name, submit_config_source_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new service configuration (version) for a managed service based on user-supplied configuration source files (for example: OpenAPI Specification).
-
#test_consumer_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#undelete_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Revives a previously deleted managed service.
Constructor Details
#initialize ⇒ ServiceManagementService
Returns a new instance of ServiceManagementService.
49 50 51 52 53 54 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 49 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-servicemanagement_v1', client_version: Google::Apis::ServicemanagementV1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
42 43 44 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 42 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
47 48 49 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 47 def quota_user @quota_user end |
Instance Method Details
#create_service(managed_service_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new managed service. A managed service is immutable, and is subject to mandatory 30-day data retention. You cannot move a service or recreate it within 30 days after deletion. One producer project can own no more than 500 services. For security and reliability purposes, a production service should be hosted in a dedicated producer project. Operation
169 170 171 172 173 174 175 176 177 178 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 169 def create_service(managed_service_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services', ) command.request_representation = Google::Apis::ServicemanagementV1::ManagedService::Representation command.request_object = managed_service_object command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_service_config(service_name, service_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Creates a new service configuration (version) for a managed service. This method only stores the service configuration. To roll out the service configuration to backend systems please call CreateServiceRollout. Only the 100 most recent service configurations and ones referenced by existing rollouts are kept for each service. The rest will be deleted eventually.
541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 541 def create_service_config(service_name, service_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services/{serviceName}/configs', ) command.request_representation = Google::Apis::ServicemanagementV1::Service::Representation command.request_object = service_object command.response_representation = Google::Apis::ServicemanagementV1::Service::Representation command.response_class = Google::Apis::ServicemanagementV1::Service command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_service_rollout(service_name, rollout_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new service configuration rollout. Based on rollout, the Google Service Management will roll out the service configurations to different backend services. For example, the logging configuration will be pushed to Google Cloud Logging. Please note that any previous pending and running Rollouts and associated Operations will be automatically cancelled so that the latest Rollout will not be blocked by previous Rollouts. Only the 100 most recent (in any state) and the last 10 successful (if not already part of the set of 100 most recent) rollouts are kept for each service. The rest will be deleted eventually. Operation
816 817 818 819 820 821 822 823 824 825 826 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 816 def create_service_rollout(service_name, rollout_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services/{serviceName}/rollouts', ) command.request_representation = Google::Apis::ServicemanagementV1::Rollout::Representation command.request_object = rollout_object command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Deletes a managed service. This method will change the service to the Soft-
Delete state for 30 days. Within this period, service producers may call
UndeleteService to restore the service. After 30 days, the service will be
permanently deleted. Operation
205 206 207 208 209 210 211 212 213 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 205 def delete_service(service_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1/services/{serviceName}', ) command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_service_config_report(generate_config_report_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::GenerateConfigReportResponse
Generates and returns a report (errors, warnings and changes from existing configurations) associated with GenerateConfigReportRequest.new_value If GenerateConfigReportRequest.old_value is specified, GenerateConfigReportRequest will contain a single ChangeReport based on the comparison between GenerateConfigReportRequest.new_value and GenerateConfigReportRequest.old_value. If GenerateConfigReportRequest. old_value is not specified, this method will compare GenerateConfigReportRequest.new_value with the last pushed service configuration.
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 242 def generate_service_config_report(generate_config_report_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services:generateConfigReport', ) command.request_representation = Google::Apis::ServicemanagementV1::GenerateConfigReportRequest::Representation command.request_object = generate_config_report_request_object command.response_representation = Google::Apis::ServicemanagementV1::GenerateConfigReportResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::GenerateConfigReportResponse command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_consumer_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
697 698 699 700 701 702 703 704 705 706 707 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 697 def get_consumer_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicemanagementV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicemanagementV1::Policy::Representation command.response_class = Google::Apis::ServicemanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
77 78 79 80 81 82 83 84 85 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 77 def get_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/{+name}', ) command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ManagedService
Gets a managed service. Authentication is required unless the service is public.
275 276 277 278 279 280 281 282 283 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 275 def get_service(service_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}', ) command.response_representation = Google::Apis::ServicemanagementV1::ManagedService::Representation command.response_class = Google::Apis::ServicemanagementV1::ManagedService command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_config(service_name, config_id, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Gets a service configuration (version) for a managed service.
580 581 582 583 584 585 586 587 588 589 590 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 580 def get_service_config(service_name, config_id, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}/configs/{configId}', ) command.response_representation = Google::Apis::ServicemanagementV1::Service::Representation command.response_class = Google::Apis::ServicemanagementV1::Service command.params['serviceName'] = service_name unless service_name.nil? command.params['configId'] = config_id unless config_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_configuration(service_name, config_id: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Service
Gets a service configuration (version) for a managed service.
312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 312 def get_service_configuration(service_name, config_id: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}/config', ) command.response_representation = Google::Apis::ServicemanagementV1::Service::Representation command.response_class = Google::Apis::ServicemanagementV1::Service command.params['serviceName'] = service_name unless service_name.nil? command.query['configId'] = config_id unless config_id.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 348 def get_service_iam_policy(resource, get_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:getIamPolicy', ) command.request_representation = Google::Apis::ServicemanagementV1::GetIamPolicyRequest::Representation command.request_object = get_iam_policy_request_object command.response_representation = Google::Apis::ServicemanagementV1::Policy::Representation command.response_class = Google::Apis::ServicemanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_service_rollout(service_name, rollout_id, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Rollout
Gets a service configuration rollout.
852 853 854 855 856 857 858 859 860 861 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 852 def get_service_rollout(service_name, rollout_id, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}/rollouts/{rolloutId}', ) command.response_representation = Google::Apis::ServicemanagementV1::Rollout::Representation command.response_class = Google::Apis::ServicemanagementV1::Rollout command.params['serviceName'] = service_name unless service_name.nil? command.params['rolloutId'] = rollout_id unless rollout_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListOperationsResponse
Lists service operations that match the specified filter in the request.
132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 132 def list_operations(filter: nil, name: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/operations', ) command.response_representation = Google::Apis::ServicemanagementV1::ListOperationsResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::ListOperationsResponse command.query['filter'] = filter unless filter.nil? command.query['name'] = name unless name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_configs(service_name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServiceConfigsResponse
Lists the history of the service configuration for a managed service, from the newest to the oldest.
620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 620 def list_service_configs(service_name, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}/configs', ) command.response_representation = Google::Apis::ServicemanagementV1::ListServiceConfigsResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::ListServiceConfigsResponse command.params['serviceName'] = service_name unless service_name.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_service_rollouts(service_name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServiceRolloutsResponse
Lists the history of the service configuration rollouts for a managed service, from the newest to the oldest.
895 896 897 898 899 900 901 902 903 904 905 906 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 895 def list_service_rollouts(service_name, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services/{serviceName}/rollouts', ) command.response_representation = Google::Apis::ServicemanagementV1::ListServiceRolloutsResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::ListServiceRolloutsResponse command.params['serviceName'] = service_name unless service_name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_services(consumer_id: nil, page_size: nil, page_token: nil, producer_project_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::ListServicesResponse
Lists managed services. Returns all public services. For authenticated users, also returns all services the calling user has "servicemanagement.services.get" permission for.
390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 390 def list_services(consumer_id: nil, page_size: nil, page_token: nil, producer_project_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1/services', ) command.response_representation = Google::Apis::ServicemanagementV1::ListServicesResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::ListServicesResponse command.query['consumerId'] = consumer_id unless consumer_id.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['producerProjectId'] = producer_project_id unless producer_project_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_consumer_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
734 735 736 737 738 739 740 741 742 743 744 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 734 def set_consumer_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicemanagementV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicemanagementV1::Policy::Representation command.response_class = Google::Apis::ServicemanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Policy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
428 429 430 431 432 433 434 435 436 437 438 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 428 def set_service_iam_policy(resource, set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ServicemanagementV1::SetIamPolicyRequest::Representation command.request_object = set_iam_policy_request_object command.response_representation = Google::Apis::ServicemanagementV1::Policy::Representation command.response_class = Google::Apis::ServicemanagementV1::Policy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#submit_config_source(service_name, submit_config_source_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Creates a new service configuration (version) for a managed service based on user-supplied configuration source files (for example: OpenAPI Specification). This method stores the source configurations as well as the generated service configuration. To rollout the service configuration to other services, please call CreateServiceRollout. Only the 100 most recent configuration sources and ones referenced by existing service configurtions are kept for each service. The rest will be deleted eventually. Operation
661 662 663 664 665 666 667 668 669 670 671 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 661 def submit_config_source(service_name, submit_config_source_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services/{serviceName}/configs:submit', ) command.request_representation = Google::Apis::ServicemanagementV1::SubmitConfigSourceRequest::Representation command.request_object = submit_config_source_request_object command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_consumer_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 773 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicemanagementV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicemanagementV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_service_iam_permissions(resource, test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::TestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
467 468 469 470 471 472 473 474 475 476 477 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 467 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ServicemanagementV1::TestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ServicemanagementV1::TestIamPermissionsResponse::Representation command.response_class = Google::Apis::ServicemanagementV1::TestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#undelete_service(service_name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ServicemanagementV1::Operation
Revives a previously deleted managed service. The method restores the service using the configuration at the time the service was deleted. The target service must exist and must have been deleted within the last 30 days. Operation
504 505 506 507 508 509 510 511 512 |
# File 'lib/google/apis/servicemanagement_v1/service.rb', line 504 def undelete_service(service_name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1/services/{serviceName}:undelete', ) command.response_representation = Google::Apis::ServicemanagementV1::Operation::Representation command.response_class = Google::Apis::ServicemanagementV1::Operation command.params['serviceName'] = service_name unless service_name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |