Class: Google::Apis::ServicemanagementV1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServicemanagementV1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
5004 5005 5006 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
4971 4972 4973 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4971 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServicemanagementV1::Field>
The list of fields.
Corresponds to the JSON property fields
4976 4977 4978 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4976 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
4981 4982 4983 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4981 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
4986 4987 4988 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4986 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
4991 4992 4993 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4991 def @options end |
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
4997 4998 4999 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4997 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
5002 5003 5004 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5002 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5009 5010 5011 5012 5013 5014 5015 5016 5017 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5009 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |