Class: Google::Apis::ServicemanagementV1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



4978
4979
4980
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4978

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


4945
4946
4947
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4945

def edition
  @edition
end

#fieldsArray<Google::Apis::ServicemanagementV1::Field>

The list of fields. Corresponds to the JSON property fields



4950
4951
4952
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4950

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


4955
4956
4957
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4955

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


4960
4961
4962
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4960

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



4965
4966
4967
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4965

def options
  @options
end

#source_contextGoogle::Apis::ServicemanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



4971
4972
4973
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4971

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


4976
4977
4978
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4976

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4983
4984
4985
4986
4987
4988
4989
4990
4991
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4983

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end