Class: Google::Apis::ServicemanagementV1::Type
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::Type
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.
Instance Attribute Summary collapse
-
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
-
#fields ⇒ Array<Google::Apis::ServicemanagementV1::Field>
The list of fields.
-
#name ⇒ String
The fully qualified message name.
-
#oneofs ⇒ Array<String>
The list of types appearing in
oneofdefinitions in this type. -
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
-
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContextrepresents information about the source of a protobuf element, like the file in which it is defined. -
#syntax ⇒ String
The source syntax.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Type
constructor
A new instance of Type.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Type
Returns a new instance of Type.
4978 4979 4980 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#edition ⇒ String
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
Corresponds to the JSON property edition
4945 4946 4947 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4945 def edition @edition end |
#fields ⇒ Array<Google::Apis::ServicemanagementV1::Field>
The list of fields.
Corresponds to the JSON property fields
4950 4951 4952 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4950 def fields @fields end |
#name ⇒ String
The fully qualified message name.
Corresponds to the JSON property name
4955 4956 4957 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4955 def name @name end |
#oneofs ⇒ Array<String>
The list of types appearing in oneof definitions in this type.
Corresponds to the JSON property oneofs
4960 4961 4962 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4960 def oneofs @oneofs end |
#options ⇒ Array<Google::Apis::ServicemanagementV1::Option>
The protocol buffer options.
Corresponds to the JSON property options
4965 4966 4967 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4965 def @options end |
#source_context ⇒ Google::Apis::ServicemanagementV1::SourceContext
SourceContext represents information about the source of a protobuf element,
like the file in which it is defined.
Corresponds to the JSON property sourceContext
4971 4972 4973 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4971 def source_context @source_context end |
#syntax ⇒ String
The source syntax.
Corresponds to the JSON property syntax
4976 4977 4978 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4976 def syntax @syntax end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4983 4984 4985 4986 4987 4988 4989 4990 4991 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4983 def update!(**args) @edition = args[:edition] if args.key?(:edition) @fields = args[:fields] if args.key?(:fields) @name = args[:name] if args.key?(:name) @oneofs = args[:oneofs] if args.key?(:oneofs) @options = args[:options] if args.key?(:options) @source_context = args[:source_context] if args.key?(:source_context) @syntax = args[:syntax] if args.key?(:syntax) end |