Class: Google::Apis::ServicemanagementV1::Type

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb

Overview

A protocol buffer message type. New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Type

Returns a new instance of Type.



4939
4940
4941
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4939

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#editionString

The source edition string, only valid when syntax is SYNTAX_EDITIONS. Corresponds to the JSON property edition

Returns:

  • (String)


4906
4907
4908
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4906

def edition
  @edition
end

#fieldsArray<Google::Apis::ServicemanagementV1::Field>

The list of fields. Corresponds to the JSON property fields



4911
4912
4913
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4911

def fields
  @fields
end

#nameString

The fully qualified message name. Corresponds to the JSON property name

Returns:

  • (String)


4916
4917
4918
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4916

def name
  @name
end

#oneofsArray<String>

The list of types appearing in oneof definitions in this type. Corresponds to the JSON property oneofs

Returns:

  • (Array<String>)


4921
4922
4923
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4921

def oneofs
  @oneofs
end

#optionsArray<Google::Apis::ServicemanagementV1::Option>

The protocol buffer options. Corresponds to the JSON property options



4926
4927
4928
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4926

def options
  @options
end

#source_contextGoogle::Apis::ServicemanagementV1::SourceContext

SourceContext represents information about the source of a protobuf element, like the file in which it is defined. Corresponds to the JSON property sourceContext



4932
4933
4934
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4932

def source_context
  @source_context
end

#syntaxString

The source syntax. Corresponds to the JSON property syntax

Returns:

  • (String)


4937
4938
4939
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4937

def syntax
  @syntax
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4944
4945
4946
4947
4948
4949
4950
4951
4952
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 4944

def update!(**args)
  @edition = args[:edition] if args.key?(:edition)
  @fields = args[:fields] if args.key?(:fields)
  @name = args[:name] if args.key?(:name)
  @oneofs = args[:oneofs] if args.key?(:oneofs)
  @options = args[:options] if args.key?(:options)
  @source_context = args[:source_context] if args.key?(:source_context)
  @syntax = args[:syntax] if args.key?(:syntax)
end