Class: Google::Apis::ServicemanagementV1::UsageRule
- Inherits:
-
Object
- Object
- Google::Apis::ServicemanagementV1::UsageRule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/servicemanagement_v1/classes.rb,
lib/google/apis/servicemanagement_v1/representations.rb,
lib/google/apis/servicemanagement_v1/representations.rb
Overview
Usage configuration rules for the service.
Instance Attribute Summary collapse
-
#allow_unregistered_calls ⇒ Boolean
(also: #allow_unregistered_calls?)
Use this rule to configure unregistered calls for the service.
-
#selector ⇒ String
Selects the methods to which this rule applies.
-
#skip_service_control ⇒ Boolean
(also: #skip_service_control?)
If true, the selected method should skip service control and the control plane features, such as quota and billing, will not be available.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsageRule
constructor
A new instance of UsageRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsageRule
Returns a new instance of UsageRule.
5047 5048 5049 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_unregistered_calls ⇒ Boolean Also known as: allow_unregistered_calls?
Use this rule to configure unregistered calls for the service. Unregistered
calls are calls that do not contain consumer project identity. (Example: calls
that do not contain an API key). WARNING: By default, API methods do not allow
unregistered calls, and each method call must be identified by a consumer
project identity.
Corresponds to the JSON property allowUnregisteredCalls
5029 5030 5031 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5029 def allow_unregistered_calls @allow_unregistered_calls end |
#selector ⇒ String
Selects the methods to which this rule applies. Use '*' to indicate all
methods in all APIs. Refer to selector for syntax details.
Corresponds to the JSON property selector
5036 5037 5038 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5036 def selector @selector end |
#skip_service_control ⇒ Boolean Also known as: skip_service_control?
If true, the selected method should skip service control and the control plane
features, such as quota and billing, will not be available. This flag is used
by Google Cloud Endpoints to bypass checks for internal methods, such as
service health check methods.
Corresponds to the JSON property skipServiceControl
5044 5045 5046 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5044 def skip_service_control @skip_service_control end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5052 5053 5054 5055 5056 |
# File 'lib/google/apis/servicemanagement_v1/classes.rb', line 5052 def update!(**args) @allow_unregistered_calls = args[:allow_unregistered_calls] if args.key?(:allow_unregistered_calls) @selector = args[:selector] if args.key?(:selector) @skip_service_control = args[:skip_service_control] if args.key?(:skip_service_control) end |